@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rd.h,v 1.187 2008-07-31 13:38:46 fredg Exp $
+//      $Id: rd.h,v 1.188.2.1 2008-11-24 18:25:21 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -104,6 +104,11 @@
  */
 #define RDCATCHD_TCP_PORT 6006
 
+/*
+ * Minimum event ID for dynamic (RML-controlled) recordings
+ */
+#define RDCATCHD_DYNAMIC_BASE_ID 1000000000
+
 /*
  * Default Local GPIO Device
  */
@@ -405,6 +410,11 @@ struct RDMeterBlock {
  */
 #define RD_IMAGE_FILE_FILTER "Image Files (*.png *.bmp *.xbm *.xpm *.pbm *.pgm *.ppm *.jpg *.mng *.gif *.PNG *.BMP *.XBM *.XPM *.PBM *.PGM *.PPM *.JPG *.MNG *.GIF)\nAll Files (*.*)"
 
+/*
+ * Loadable Module Filter for QFileDialog
+ */
+#define RD_MODULE_FILE_FILTER "Rivendell Loadable Modules (*.rlm)\nAll Files (*.*)"
+
 /*
  * Web Interface Settings
  */
