@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay_conf.cpp,v 1.27 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdairplay_conf.cpp,v 1.30.2.1 2008-12-02 20:35:21 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,9 +19,10 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-
+#include <rddb.h>
 #include <rdconf.h>
 #include <rdairplay_conf.h>
+#include <rdescape_string.h>
 
 
 //
@@ -30,7 +31,7 @@
 RDAirPlayConf::RDAirPlayConf(const QString &station,unsigned instance,
 			     const QString &tablename)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   air_station=station;
@@ -40,24 +41,24 @@ RDAirPlayConf::RDAirPlayConf(const QString &station,unsigned instance,
   sql=QString().
     sprintf("select ID from %s where STATION=\"%s\" && INSTANCE=%d",
 	    (const char *)air_tablename,
-	    (const char *)air_station,
+	    (const char *)RDEscapeString(air_station),
 	    air_instance);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     sql=QString().
       sprintf("insert into %s set STATION=\"%s\",INSTANCE=%d",
 	      (const char *)air_tablename,
-	      (const char *)air_station,
+	      (const char *)RDEscapeString(air_station),
 	      air_instance);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
     sql=QString().
       sprintf("select ID from %s where STATION=\"%s\" && INSTANCE=%d",
 	      (const char *)air_tablename,
-	      (const char *)air_station,
+	      (const char *)RDEscapeString(air_station),
 	      air_instance);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     q->first();
   }
   air_id=q->value(0).toUInt();
@@ -435,14 +436,14 @@ void RDAirPlayConf::setExitCode(RDAirPlayConf::ExitCode code) const
 bool RDAirPlayConf::exitPasswordValid(const QString &passwd) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   sql=QString().sprintf("select EXIT_PASSWORD from %s where \
                          STATION=\"%s\" && EXIT_PASSWORD=PASSWORD(\"%s\")",
 			(const char *)air_tablename,
 			(const char *)air_station,
 			(const char *)passwd);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->size()>0) {
     delete q;
     return true;
@@ -455,17 +456,29 @@ bool RDAirPlayConf::exitPasswordValid(const QString &passwd) const
 void RDAirPlayConf::setExitPassword(const QString &passwd) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   sql=QString().sprintf ("update %s set EXIT_PASSWORD=PASSWORD(\"%s\") \
                           where STATION=\"%s\"",(const char *)air_tablename,
 			 (const char *)passwd,
 			 (const char *)air_station);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
+QString RDAirPlayConf::skinPath() const
+{
+  return RDGetSqlValue(air_tablename,"ID",air_id,"SKIN_PATH").toString();
+}
+
+
+void RDAirPlayConf::setSkinPath(const QString &path) const
+{
+  SetRow("SKIN_PATH",path);
+}
+
+
 RDAirPlayConf::StartMode RDAirPlayConf::startMode(int lognum) const
 {
   return (RDAirPlayConf::StartMode)
@@ -560,9 +573,35 @@ void RDAirPlayConf::setLogCurrentLine(int lognum,int line) const
 }
 
 
-void RDAirPlayConf::SetRow(QString param,int value) const
+unsigned RDAirPlayConf::logNowCart(int lognum) const
 {
-  QSqlQuery *q;
+  return RDGetSqlValue(air_tablename,"ID",air_id,QString().
+		      sprintf("LOG%d_NOW_CART",lognum)).toUInt();
+}
+
+
+void RDAirPlayConf::setLogNowCart(int lognum,unsigned cartnum) const
+{
+  SetRow(QString().sprintf("LOG%d_NOW_CART",lognum),cartnum);
+}
+
+
+unsigned RDAirPlayConf::logNextCart(int lognum) const
+{
+  return RDGetSqlValue(air_tablename,"ID",air_id,QString().
+		      sprintf("LOG%d_NEXT_CART",lognum)).toUInt();
+}
+
+
+void RDAirPlayConf::setLogNextCart(int lognum,unsigned cartnum) const
+{
+  SetRow(QString().sprintf("LOG%d_NEXT_CART",lognum),cartnum);
+}
+
+
+void RDAirPlayConf::SetRow(const QString &param,int value) const
+{
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().
@@ -572,23 +611,40 @@ void RDAirPlayConf::SetRow(QString param,int value) const
 	    value,
 	    (const char *)air_station,
 	    air_instance);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
-void RDAirPlayConf::SetRow(QString param,QString value) const
+void RDAirPlayConf::SetRow(const QString &param,unsigned value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
+  QString sql;
+
+  sql=QString().
+    sprintf("UPDATE %s SET %s=%u WHERE STATION=\"%s\" && INSTANCE=%d",
+	    (const char *)air_tablename,
+	    (const char *)param,
+	    value,
+	    (const char *)air_station,
+	    air_instance);
+  q=new RDSqlQuery(sql);
+  delete q;
+}
+
+
+void RDAirPlayConf::SetRow(const QString &param,const QString &value) const
+{
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().
     sprintf("UPDATE %s SET %s=\"%s\" WHERE STATION=\"%s\" && INSTANCE=%d",
 	    (const char *)air_tablename,
-	    (const char *)param,
-	    (const char *)value,
+	    (const char *)RDEscapeString(param),
+	    (const char *)RDEscapeString(value),
 	    (const char *)air_station,
 	    air_instance);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
