@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart.cpp,v 1.61.2.1 2008-10-28 19:24:20 fredg Exp $
+//      $Id: rdcart.cpp,v 1.61.2.2 2008-11-30 16:33:57 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -675,9 +675,8 @@ void RDCart::setMetadata(RDWaveData *data)
 		    RDEscapeString(data->agency()).utf8());
   }
   if(!data->publisher().isEmpty()) {
-    sql+=QString().sprintf("PUBLISHER=\"%s\",",
-			   (const char *)
-					   RDEscapeString(data->publisher()).utf8());
+    sql+=QString().sprintf("PUBLISHER=\"%s\",",(const char *)
+			   RDEscapeString(data->publisher()).utf8());
   }
   if(!data->composer().isEmpty()) {
     sql+=QString().sprintf("COMPOSER=\"%s\",",
