@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart.h,v 1.30 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdcart.h,v 1.34 2007-10-05 13:50:31 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,12 +20,12 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qsqldatabase.h>
 #include <qdatetime.h>
 
-#include <rwavedata.h>
+#include <rdwavedata.h>
 
 #include <rdcut.h>
+#include <rddb.h>
 
 #ifndef RDCART_H
 #define RDCART_H
@@ -59,6 +59,9 @@ class RDCart
   QDate year() const;
   void setYear(const QDate &date) const;
   void setYear() const;
+  QString schedCodes() const;
+  void setSchedCodes(const QString &sched_codes) const;
+  void updateSchedCodes(const QString &add_codes,const QString &remove_codes) const;
   QString label() const;
   void setLabel(const QString &label) const;
   QString client() const;
@@ -82,6 +85,8 @@ class RDCart
   void setAverageLength(unsigned length) const;
   unsigned averageSegueLength() const;
   void setAverageSegueLength(unsigned length) const;
+  unsigned averageHookLength() const;
+  void setAverageHookLength(unsigned length) const;
   unsigned cutQuantity() const;
   void setCutQuantity(unsigned quan) const;
   unsigned lastCutPlayed() const;
@@ -106,8 +111,8 @@ class RDCart
   void setOwner(const QString &owner) const;
   QString macros() const;
   void setMacros(const QString &cmds) const;
-  void getMetadata(RWaveData *data);
-  void setMetadata(RWaveData *data);
+  void getMetadata(RDWaveData *data);
+  void setMetadata(RDWaveData *data);
   void updateLength() const;
   void updateLength(bool enforce_length,unsigned length) const;
   void resetRotation() const;
@@ -122,9 +127,9 @@ class RDCart
   static QString usageText(RDCart::UsageCode usage);
   
  private:
-  QString GetNextCut(QSqlQuery *q) const;
+  QString GetNextCut(RDSqlQuery *q) const;
   int GetNextFreeCut() const;
-  RDCut::Validity ValidateCut(QSqlQuery *q,bool enforce_length,
+  RDCut::Validity ValidateCut(RDSqlQuery *q,bool enforce_length,
 			      unsigned length,bool *time_ok) const;
   void SetRow(const QString &param,const QString &value) const;
   void SetRow(const QString &param,unsigned value) const;
