@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatch_connect.h,v 1.14 2007/04/03 23:16:47 fredg Exp $
+//      $Id: rdcatch_connect.h,v 1.15 2008-10-02 18:52:11 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -65,7 +65,7 @@ class RDCatchConnect : public QObject
  signals:
   void connected(int serial,bool state);
   void statusChanged(int serial,unsigned channel,RDDeck::Status status,
-		     int id);
+		     int id,const QString &cutname);
   void monitorChanged(int serial,unsigned channel,bool state);
   void meterLevel(int serial,int deck,int chan,int level);
   void eventUpdated(int id);
