@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdconfig.cpp,v 1.17 2007/12/31 18:49:08 fredg Exp $
+//      $Id: rdconfig.cpp,v 1.19 2008-04-09 16:58:38 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,6 +22,7 @@
 
 #ifndef WIN32
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <pwd.h>
 #include <grp.h>
 #endif
@@ -120,6 +121,73 @@ int RDConfig::mysqlHeartbeatInterval() const
 }
 
 
+RDConfig::LogFacility RDConfig::logFacility() const
+{
+  return conf_log_facility;
+}
+
+
+QString RDConfig::logDirectory() const
+{
+  return conf_log_directory;
+}
+
+
+QString RDConfig::logCoreDumpDirectory() const
+{
+  return conf_log_core_dump_directory;
+}
+
+
+QString RDConfig::logPattern() const
+{
+  return conf_log_pattern;
+}
+
+
+void RDConfig::log(const QString &module,LogPriority prio,const QString &msg)
+{
+#ifndef WIN32
+  QDateTime dt;
+  QString filename;
+  FILE *f=NULL;
+
+  switch(conf_log_facility) {
+    case RDConfig::LogSyslog:
+      syslog((int)prio,"%s",(const char *)msg);
+      break;
+
+    case RDConfig::LogFile:
+      if(conf_log_directory.isEmpty()||conf_log_pattern.isEmpty()) {
+	return;
+      }
+      filename=QString().sprintf("%s/%s",(const char *)conf_log_directory,
+				 (const char *)conf_log_pattern);
+      dt=QDateTime(QDate::currentDate(),QTime::currentTime());
+      filename.replace("%n",module);
+      filename.replace("%d",dt.date().toString("dd"));
+      filename.replace("%M",dt.date().toString("MM"));
+      filename.replace("%Y",dt.date().toString("yyyy"));
+      filename.replace("%h",dt.time().toString("hh"));
+      filename.replace("%m",dt.time().toString("mm"));
+      filename.replace("%s",dt.time().toString("ss"));
+      if((f=fopen(filename,"a"))!=NULL) {
+	fprintf(f,"%s: %s\n",(const char *)dt.
+		toString("dd/MM/yyyy - hh:mm:ss.zzz "),
+		(const char *)msg);
+	fclose(f);
+      }
+      chmod(filename,S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH);
+      chown(filename,uid(),gid());
+      break;
+
+    case RDConfig::LogNone:
+      break;
+  }
+#endif  // WIN32
+}
+
+
 int RDConfig::alsaPeriodQuantity() const
 {
   return conf_alsa_period_quantity;
@@ -278,6 +346,7 @@ QString RDConfig::destination(unsigned n)
 void RDConfig::load()
 {
   char sname[256];
+  QString facility;
 #ifndef WIN32
   struct passwd *user;
   struct group *groups;
@@ -313,6 +382,21 @@ void RDConfig::load()
   conf_mysql_heartbeat_interval=
     profile->intValue("mySQL","HeartbeatInterval",
 		      DEFAULT_MYSQL_HEARTBEAT_INTERVAL);
+
+  facility=profile->stringValue("Logs","Facility",DEFAULT_LOG_FACILITY).lower();
+  if(facility=="syslog") {
+    conf_log_facility=RDConfig::LogSyslog;
+  }
+  if(facility=="file") {
+    conf_log_facility=RDConfig::LogFile;
+  }
+  conf_log_directory=profile->stringValue("Logs","LogDirectory","");
+  conf_log_pattern=profile->stringValue("Logs","LogPattern",
+					DEFAULT_LOG_PATTERN);
+  conf_log_core_dump_directory=
+    profile->stringValue("Logs","CoreDumpDirectory",
+			 DEFAULT_LOG_CORE_DUMP_DIRECTORY);
+
   conf_alsa_period_quantity=
     profile->intValue("Alsa","PeriodQuantity",RD_ALSA_DEFAULT_PERIOD_QUANTITY);
   conf_alsa_period_size=
@@ -369,6 +453,10 @@ void RDConfig::clear()
   conf_mysql_password="";
   conf_mysql_driver="";
   conf_mysql_heartbeat_interval=DEFAULT_MYSQL_HEARTBEAT_INTERVAL;
+  conf_log_facility=RDConfig::LogSyslog;
+  conf_log_directory="";
+  conf_log_core_dump_directory=DEFAULT_LOG_CORE_DUMP_DIRECTORY;
+  conf_log_pattern=DEFAULT_LOG_PATTERN;
   conf_alsa_period_quantity=RD_ALSA_DEFAULT_PERIOD_QUANTITY;
   conf_alsa_period_size=RD_ALSA_DEFAULT_PERIOD_SIZE;
   conf_station_name="";
