@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcut.cpp,v 1.59 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdcut.cpp,v 1.67.2.1 2008-11-30 16:33:57 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,14 +35,16 @@
 
 #include <rdcut.h>
 #include <rdtextvalidator.h>
-
+#include <rdconfig.h>
+#include <rddb.h>
+#include <rdescape_string.h>
 
 //
 // Global Classes
 //
 RDCut::RDCut(const QString &name,bool create,QSqlDatabase *db)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   cut_db=db;
@@ -53,7 +55,7 @@ RDCut::RDCut(const QString &name,bool create,QSqlDatabase *db)
   if(create) {
     sql=QString().sprintf("INSERT INTO CUTS SET CUT_NAME=\"%s\"",
 			  (const char *)cut_name);
-    q=new QSqlQuery(sql,cut_db);
+    q=new RDSqlQuery(sql,cut_db);
     delete q;
   }
   sscanf((const char *)name+7,"%u",&cut_number);
@@ -62,7 +64,7 @@ RDCut::RDCut(const QString &name,bool create,QSqlDatabase *db)
 
 RDCut::RDCut(unsigned cartnum,int cutnum,bool create,QSqlDatabase *db)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   cut_db=db;
@@ -73,7 +75,7 @@ RDCut::RDCut(unsigned cartnum,int cutnum,bool create,QSqlDatabase *db)
   if(create) {
     sql=QString().sprintf("INSERT INTO CUTS SET CUT_NAME=\"%s\"",
 			  (const char *)cut_name);
-    q=new QSqlQuery(sql,cut_db);
+    q=new RDSqlQuery(sql,cut_db);
     delete q;
   }
   cut_number=cutnum;
@@ -98,10 +100,7 @@ bool RDCut::audioExists() const
     return false;
   }
 #ifndef WIN32
-  RDWaveFile *wave=new RDWaveFile(QString().sprintf("%s/%s.%s",
-						  RD_AUDIO_ROOT,
-						  (const char *)cut_name,
-						  RD_AUDIO_EXTENSION));
+  RDWaveFile *wave=new RDWaveFile(RDCut::pathName(cut_name)); 
   if(!wave->openWave()) {
     delete wave;
     return false;
@@ -127,13 +126,13 @@ bool RDCut::isValid(const QTime &time) const
 bool RDCut::isValid(const QDateTime &datetime) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   sql=QString().sprintf("select MON,TUE,WED,THU,FRI,SAT,SUN,EVERGREEN,\
                          START_DATETIME,END_DATETIME,START_DAYPART,END_DAYPART\
                          from CUTS where CUT_NAME=\"%s\"",
 			(const char *)cut_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     return false;
@@ -648,6 +647,18 @@ void RDCut::setSegueEndPoint(int point) const
 }
 
 
+int RDCut::segueGain() const
+{
+  return RDGetSqlValue("CUTS","CUT_NAME",cut_name,"SEGUE_GAIN",cut_db).toInt();
+}
+
+
+void RDCut::setSegueGain(int gain) const
+{
+  SetRow("SEGUE_GAIN",gain);
+}
+
+
 int RDCut::hookStartPoint(bool calc) const
 {
   int n;
@@ -768,7 +779,7 @@ void RDCut::logPlayout() const
 		      (const char *)QDateTime(QDate::currentDate(),
 		        QTime::currentTime()).toString("yyyy-MM-dd hh:mm:ss"),
 		      playCounter()+1,localCounter()+1,(const char *)cut_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -777,7 +788,7 @@ bool RDCut::copyTo(const QString &cutname) const
 {
 #ifndef WIN32
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // Copy the Database Record
@@ -790,7 +801,7 @@ bool RDCut::copyTo(const QString &cutname) const
                        SEGUE_END_POINT,HOOK_START_POINT,HOOK_END_POINT,\
                        TALK_START_POINT,TALK_END_POINT from CUTS\
                        where CUT_NAME=\"%s\"",(const char *)cut_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     sql=QString().sprintf("update CUTS set\
                            DESCRIPTION=\"%s\",\
@@ -836,17 +847,14 @@ bool RDCut::copyTo(const QString &cutname) const
 			  (const char *)cutname);
   }
   delete q;
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
   // Copy the Audio
   //
-  QString srcname=
-    QString().sprintf("%s/%s.wav",RD_AUDIO_ROOT,(const char *)cut_name);
-  QString destname=QString().sprintf("%s/%s.%s",RD_AUDIO_ROOT,
-				     (const char *)cutname,
-				     RD_AUDIO_EXTENSION);
+  QString srcname=RDCut::pathName(cut_name); 
+  QString destname=RDCut::pathName(cutname); 
   FileCopy(srcname,destname);
 
 #endif
@@ -857,14 +865,14 @@ bool RDCut::copyTo(const QString &cutname) const
 void RDCut::getMetadata(RDWaveData *data)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   sql=QString().sprintf("select DESCRIPTION,OUTCUE,ISRC,ORIGIN_DATETIME,\
                          START_DATETIME,END_DATETIME,SEGUE_START_POINT,\
-                         SEGUE_END_POINT,START_POINT,TALK_START_POINT,\
-                         TALK_END_POINT,where CUT_NAME=\"%s\"",
+                         SEGUE_END_POINT,TALK_START_POINT,TALK_END_POINT,\
+                         START_POINT,END_POINT where CUT_NAME=\"%s\"",
 			(const char *)cut_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     data->setTitle(q->value(0).toString());
     data->setOutCue(q->value(1).toString());
@@ -875,13 +883,12 @@ void RDCut::getMetadata(RDWaveData *data)
     data->setStartTime(q->value(4).toTime());
     data->setEndDate(q->value(5).toDate());
     data->setEndTime(q->value(5).toTime());
-    if(q->value(6).toInt()!=-1) {
-      data->setSegueLength(q->value(6).toInt()-q->value(7).toInt());
-    }
-    if((q->value(8).toInt()==q->value(9).toInt())&&
-       (q->value(8).toInt()!=-1)) {
-      data->setIntroLength(q->value(10).toInt()-q->value(9).toInt());
-    }
+    data->setSegueStartPos(q->value(6).toInt());
+    data->setSegueEndPos(q->value(7).toInt());
+    data->setIntroStartPos(q->value(8).toInt());
+    data->setIntroEndPos(q->value(9).toInt());
+    data->setStartPos(q->value(10).toInt());
+    data->setEndPos(q->value(11).toInt());
     data->setMetadataFound(true);
   }
   delete q;
@@ -917,17 +924,58 @@ void RDCut::setMetadata(RDWaveData *data)
     sql+=QString().sprintf("ISRC=\"%s\",",
     (const char *)RDTextValidator::stripString(data->isrc()).utf8());
   }
-  if(data->introLength()>0) {
-    sql+=QString().sprintf("TALK_START_POINT=0,TALK_END_POINT=%d,",
-			   data->introLength());
+  if(data->startPos()>=0) {
+    sql+=QString().sprintf("START_POINT=%d,",data->startPos());
   }
-  if(data->segueLength()>0) {
-    sql+=QString().sprintf("SEGUE_START_POINT=%d,SEGUE_END_POINT=%d,",
-			   data->segueLength(),
-			   endPoint());
+  if(data->endPos()>=0) {
+    sql+=QString().sprintf("END_POINT=%d,",data->endPos());
   }
-  if(!data->startDate().isNull()) {
-    if(!data->startTime().isNull()) {
+  if((data->introStartPos()==data->startPos())&&
+     (data->introEndPos()==data->endPos())) {
+    sql+="TALK_START_POINT=-1,TALK_END_POINT=-1,";
+  }
+  else {
+    if(data->introStartPos()>=0) {
+      if(data->introStartPos()<data->startPos()) {
+	sql+=QString().sprintf("TALK_START_POINT=%d,",data->startPos());
+      }
+      else {
+	sql+=QString().sprintf("TALK_START_POINT=%d,",data->introStartPos());
+      }
+    }
+    if(data->introEndPos()>=0) {
+      if(data->introEndPos()>data->endPos()) {
+	sql+=QString().sprintf("TALK_END_POINT=%d,",data->endPos());
+      }
+      else {
+	sql+=QString().sprintf("TALK_END_POINT=%d,",data->introEndPos());
+      }
+    }
+  }
+  if(((data->segueStartPos()==data->startPos())&&
+      (data->segueEndPos()==data->endPos()))||(data->segueStartPos()==0)) {
+    sql+="SEGUE_START_POINT=-1,SEGUE_END_POINT=-1,";
+  }
+  else {
+    if(data->segueStartPos()>=0) {
+      if(data->segueStartPos()<data->startPos()) {
+	sql+=QString().sprintf("SEGUE_START_POINT=%d,",data->startPos());
+      }
+      else {
+	sql+=QString().sprintf("SEGUE_START_POINT=%d,",data->segueStartPos());
+      }
+    }
+    if(data->segueEndPos()>=0) {
+      if(data->segueEndPos()>data->endPos()) {
+	sql+=QString().sprintf("SEGUE_END_POINT=%d,",data->endPos());
+      }
+      else {
+	sql+=QString().sprintf("SEGUE_END_POINT=%d,",data->segueEndPos());
+      }
+    }
+  }
+  if(data->startDate().isValid()) {
+    if(data->startTime().isValid()) {
     sql+=QString().sprintf("START_DATETIME=\"%s %s\",",
 			   (const char *)data->startDate().
 			   toString("yyyy-MM-dd"),
@@ -939,8 +987,8 @@ void RDCut::setMetadata(RDWaveData *data)
 			     (const char *)data->startDate().
 			     toString("yyyy-MM-dd"));
     }
-    if(!data->endDate().isNull()) {
-      if(!data->endTime().isNull()) {
+    if(data->endDate().isValid()&&(data->endDate().year()<8000)) {
+      if(data->endTime().isValid()) {
 	sql+=QString().sprintf("END_DATETIME=\"%s %s\",",
 			       (const char *)data->endDate().
 			       toString("yyyy-MM-dd"),
@@ -954,10 +1002,13 @@ void RDCut::setMetadata(RDWaveData *data)
       }
     }
   }
-  sql=sql.left(sql.length()-1);
-  sql+=QString().sprintf(" where CUT_NAME=\"%s\"",(const char *)cut_name.utf8());
-  QSqlQuery *q=new QSqlQuery(sql);
-  delete q;
+  if(sql.right(1)==",") {
+    sql=sql.left(sql.length()-1);
+    sql+=QString().
+      sprintf(" where CUT_NAME=\"%s\"",(const char *)cut_name.utf8());
+    RDSqlQuery *q=new RDSqlQuery(sql);
+    delete q;
+  }
 }
 
 
@@ -967,7 +1018,7 @@ bool RDCut::checkInRecording(const QString &stationname) const
   return false;
 #else
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   RDWaveFile *wavefile=new RDWaveFile(RDCut::pathName(cut_name));
   if(!wavefile->openWave()) {
@@ -1000,7 +1051,7 @@ bool RDCut::checkInRecording(const QString &stationname) const
 			toString("hh:mm:ss"),
 			(const char *)stationname,
 			(const char *)cut_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   wavefile->closeWave();
   delete wavefile;
@@ -1019,9 +1070,7 @@ void RDCut::autoTrim(RDCut::AudioEnd end,int level)
   if(!exists()) {
     return;
   }
-  QString wavename=QString().sprintf("%s/%s.%s",(const char *)RD_AUDIO_ROOT,
-				     (const char *)cut_name,
-				     (const char *)RD_AUDIO_EXTENSION);
+  QString wavename=RDCut::pathName(cut_name); 
   RDWaveFile *wave=new RDWaveFile(wavename);
   if(!wave->openWave()) {
     delete wave;
@@ -1071,9 +1120,7 @@ void RDCut::autoSegue(int level,int length)
   if(!exists()) {
     return;
   }
-  QString wavename=QString().sprintf("%s/%s.%s",(const char *)RD_AUDIO_ROOT,
-				     (const char *)cut_name,
-				     (const char *)RD_AUDIO_EXTENSION);
+  QString wavename=RDCut::pathName(cut_name); 
   RDWaveFile *wave=new RDWaveFile(wavename);
   if(!wave->openWave()) {
     delete wave;
@@ -1112,15 +1159,13 @@ void RDCut::reset() const
 {
 #ifndef WIN32
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   int format;
 
   if(!exists()) {
     return;
   }
-  RDWaveFile *wave=new RDWaveFile(QString(RD_AUDIO_ROOT)+QString("/")+
-				cut_name+QString(".")+
-				QString(RD_AUDIO_EXTENSION));
+  RDWaveFile *wave=new RDWaveFile(RDCut::pathName(cut_name)); 
   if(wave->openWave()) {
     switch(wave->getFormatTag()) {
 	case WAVE_FORMAT_MPEG:
@@ -1139,6 +1184,7 @@ void RDCut::reset() const
                            START_POINT=0,END_POINT=%u,FADEUP_POINT=-1,\
                            FADEDOWN_POINT=-1,\
                            SEGUE_START_POINT=-1,SEGUE_END_POINT=-1,\
+		           SEGUE_GAIN=%d,\
                            HOOK_START_POINT=-1,HOOK_END_POINT=-1,\
                            TALK_START_POINT=-1,TALK_END_POINT=-1 \
                            where CUT_NAME=\"%s\"",
@@ -1148,6 +1194,7 @@ void RDCut::reset() const
 			  wave->getHeadBitRate(),
 			  wave->getChannels(),
 			  wave->getExtTimeLength(),
+			  RD_FADE_DEPTH,
 			  (const char *)cut_name);
   }
   else {
@@ -1160,12 +1207,14 @@ void RDCut::reset() const
                            START_POINT=-1,END_POINT=-1,FADEUP_POINT=-1,\
                            FADEDOWN_POINT=-1,\
                            SEGUE_START_POINT=-1,SEGUE_END_POINT=-1,\
+		           SEGUE_GAIN= %d,\
                            HOOK_START_POINT=-1,HOOK_END_POINT=-1,\
                            TALK_START_POINT=-1,TALK_END_POINT=-1 \
                            where CUT_NAME=\"%s\"",
+			   RD_FADE_DEPTH,
 			  (const char *)cut_name);
   }
-  q=new QSqlQuery(sql,cut_db);
+  q=new RDSqlQuery(sql,cut_db);
   delete q;
   wave->closeWave();
   delete wave;
@@ -1187,7 +1236,7 @@ void RDCut::disconnect(QObject *receiver,const char *member) const
 
 bool RDCut::exists(const QString &cutname)
 {
-  QSqlQuery *q=new QSqlQuery(QString().sprintf("select CUT_NAME from CUTS\
+  RDSqlQuery *q=new RDSqlQuery(QString().sprintf("select CUT_NAME from CUTS\
                                                 where CUT_NAME=\"%s\"",
 					       (const char *)cutname));
   bool ret=q->first();
@@ -1198,8 +1247,7 @@ bool RDCut::exists(const QString &cutname)
 
 QString RDCut::pathName(const QString &cutname)
 {
-  return QString().sprintf("%s/%s.%s",RD_AUDIO_ROOT,(const char *)cutname,
-			   RD_AUDIO_EXTENSION);
+  return RDConfiguration()->audioFileName(cutname); 
 }
 
 
@@ -1256,94 +1304,94 @@ bool RDCut::FileCopy(const QString &srcfile,const QString &destfile) const
 
 void RDCut::SetRow(const QString &param,const QString &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE CUTS SET %s=\"%s\" WHERE CUT_NAME=\"%s\"",
 			(const char *)param,
-			(const char *)value.utf8(),
+			(const char *)RDEscapeString(value.utf8()),
 			(const char *)cut_name);
-  q=new QSqlQuery(sql,cut_db);
+  q=new RDSqlQuery(sql,cut_db);
   delete q;
 }
 
 
 void RDCut::SetRow(const QString &param,unsigned value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE CUTS SET %s=%u WHERE CUT_NAME=\"%s\"",
 			(const char *)param,
 			value,
 			(const char *)cut_name);
-  q=new QSqlQuery(sql,cut_db);
+  q=new RDSqlQuery(sql,cut_db);
   delete q;
 }
 
 
 void RDCut::SetRow(const QString &param,int value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE CUTS SET %s=%d WHERE CUT_NAME=\"%s\"",
 			(const char *)param,
 			value,
 			(const char *)cut_name);
-  q=new QSqlQuery(sql,cut_db);
+  q=new RDSqlQuery(sql,cut_db);
   delete q;
 }
 
 
 void RDCut::SetRow(const QString &param,const QDateTime &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE CUTS SET %s=\"%s\" WHERE CUT_NAME=\"%s\"",
 			(const char *)param,
 			(const char *)value.toString("yyyy-MM-dd hh:mm:ss"),
 			(const char *)cut_name);
-  q=new QSqlQuery(sql,cut_db);
+  q=new RDSqlQuery(sql,cut_db);
   delete q;
 }
 
 
 void RDCut::SetRow(const QString &param,const QDate &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE CUTS SET %s=\"%s\" WHERE CUT_NAME=\"%s\"",
 			(const char *)param,
 			(const char *)value.toString("yyyy-MM-dd"),
 			(const char *)cut_name);
-  q=new QSqlQuery(sql,cut_db);
+  q=new RDSqlQuery(sql,cut_db);
   delete q;
 }
 
 
 void RDCut::SetRow(const QString &param,const QTime &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   sql=QString().sprintf("UPDATE CUTS SET %s=\"%s\" WHERE CUT_NAME=\"%s\"",
 			(const char *)param,
 			(const char *)value.toString("hh:mm:ss"),
 			(const char *)cut_name);
-  q=new QSqlQuery(sql,cut_db);
+  q=new RDSqlQuery(sql,cut_db);
   delete q;
 }
 
 
 void RDCut::SetRow(const QString &param) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   sql=QString().sprintf("UPDATE CUTS SET %s=NULL WHERE CUT_NAME=\"%s\"",
 			(const char *)param,
 			(const char *)cut_name);
-  q=new QSqlQuery(sql,cut_db);
+  q=new RDSqlQuery(sql,cut_db);
   delete q;
 }
