@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddropbox.h,v 1.1 2007/04/03 23:16:47 fredg Exp $
+//      $Id: rddropbox.h,v 1.3.2.1 2008-11-29 15:48:09 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -47,20 +47,28 @@ class RDDropbox
   void setToCart(unsigned cart) const;
   bool useCartchunkId() const;
   void setUseCartchunkId(bool state) const;
+  bool titleFromCartchunkId() const;
+  void setTitleFromCartchunkId(bool state) const;
   bool deleteCuts() const;
   void setDeleteCuts(bool state) const;
+  bool deleteSource() const;
+  void setDeleteSource(bool state) const;
   QString metadataPattern() const;
   void setMetadataPattern(const QString &str) const;
+  int startdateOffset() const;
+  void setStartdateOffset(int offset) const;
+  int enddateOffset() const;
+  void setEnddateOffset(int offset) const;
   bool fixBrokenFormats() const;
   void setFixBrokenFormats(bool state) const;
   QString logPath() const;
   void setLogPath(const QString &path) const;
 
  private:
-  void SetRow(QString param,int value) const;
-  void SetRow(QString param,unsigned value) const;
-  void SetRow(QString param,QString value) const;
-  void SetRow(QString param,bool value) const;
+  void SetRow(const QString &param,int value) const;
+  void SetRow(const QString &param,unsigned value) const;
+  void SetRow(const QString &param,const QString &value) const;
+  void SetRow(const QString &param,bool value) const;
   int box_id;
 };
 
