@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdevent.cpp,v 1.8 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdevent.cpp,v 1.10.2.1 2008-11-30 00:32:56 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,17 +19,17 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-
+#include <rddb.h>
 #include <rdconf.h>
 #include <rdevent.h>
-
+#include <rdescape_string.h>
 
 //
 // Global Classes
 //
 RDEvent::RDEvent(const QString &name,bool create)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   event_name=name;
@@ -37,13 +37,13 @@ RDEvent::RDEvent(const QString &name,bool create)
   if(create) {
     sql=QString().sprintf("select NAME from EVENTS where \
 (NAME=\"%s\")",(const char *)event_name);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->size()!=1) {
       delete q;
       sql=QString().
         sprintf("INSERT INTO EVENTS SET NAME=\"%s\",TITLE_SEP=100",
 		(const char *)event_name);
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
       delete q;
     }
     else {
@@ -274,16 +274,29 @@ void RDEvent::setNestedEvent(const QString &eventname)
 }
 
 
+QString RDEvent::remarks() const
+{
+  bool ok;
+  return GetStringValue("REMARKS",&ok);
+}
+
+
+void RDEvent::setRemarks(const QString &str) const
+{
+  SetRow("REMARKS",str,true);
+}
+
+
 int RDEvent::GetIntValue(const QString &field) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   int accum;
   
   sql=QString().sprintf("select %s from EVENTS where NAME=\"%s\"",
 			(const char *)field,
 			(const char *)event_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     accum=q->value(0).toInt();
     delete q;
@@ -297,13 +310,13 @@ int RDEvent::GetIntValue(const QString &field) const
 QString RDEvent::GetStringValue(const QString &field,bool *ok) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString accum;
   
   sql=QString().sprintf("select %s from EVENTS where NAME=\"%s\"",
 			(const char *)field,
 			(const char *)event_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     if(q->value(0).isNull()) {
       *ok=false;
@@ -322,27 +335,27 @@ QString RDEvent::GetStringValue(const QString &field,bool *ok) const
 
 void RDEvent::SetRow(const QString &param,int value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE EVENTS SET %s=%d WHERE NAME=\"%s\"",
 			(const char *)param,
 			value,
 			(const char *)event_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDEvent::SetRow(const QString &param,const QString &value,bool ok) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   if(ok) {
     sql=QString().sprintf("UPDATE EVENTS SET %s=\"%s\" WHERE NAME=\"%s\"",
 			  (const char *)param,
-			  (const char *)value,
+			  (const char *)RDEscapeString(value),
 			  (const char *)event_name);
   }
   else {
@@ -350,7 +363,7 @@ void RDEvent::SetRow(const QString &param,const QString &value,bool ok) const
 			  (const char *)param,
 			  (const char *)event_name);
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -389,6 +402,3 @@ void RDEvent::setTitleSep(unsigned titlesep)
 {
   SetRow("TITLE_SEP",titlesep);
 }
-
-
-
