@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdlistselector.h,v 1.1 2007-09-14 14:06:24 fredg Exp $
+//    $Id: rdlistselector.h,v 1.1.2.1 2008-11-04 19:38:08 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -59,9 +59,9 @@ class RDListSelector : public QHBox
   void sourceSetCurrentItem(int item);
   void destSetCurrentItem(int item);
   QListBoxItem *sourceFindItem(const QString &text,
-			       ComparisonFlags compare=BeginsWith) const;
+			       ComparisonFlags compare=ExactMatch) const;
   QListBoxItem *destFindItem(const QString &text,
-			     ComparisonFlags compare=BeginsWith) const;
+			     ComparisonFlags compare=ExactMatch) const;
   void clear();
   
  private slots:
