@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_line.h,v 1.80 2007/12/29 18:16:10 fredg Exp $
+//      $Id: rdlog_line.h,v 1.81.2.1 2008-12-03 20:24:41 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -36,7 +36,7 @@ class RDLogLine
  public:
   enum StartTimeType {Imported=0,Logged=1,Predicted=2,Actual=3,Initial=4};
   enum TimeType {Relative=0,Hard=1};
-  enum TransType {Play=0,Segue=1,Stop=2,Overlap=3,NoTrans=255};
+  enum TransType {Play=0,Segue=1,Stop=2,NoTrans=255};
   enum TransEdge {AllTrans=0,LeadingTrans=1,TrailingTrans=2};
   enum Source {Manual=0,Traffic=1,Music=2,Template=3,Tracker=4};
   enum Status {Scheduled=1,Playing=2,Auditioning=3,Finished=4,
@@ -49,6 +49,7 @@ class RDLogLine
   enum PlaySource {UnknownSource=0,MainLog=1,AuxLog1=2,AuxLog2=3,SoundPanel=4};
   enum PointerSource {CartPointer=0,LogPointer=1,AutoPointer=2};
   RDLogLine();
+  RDLogLine(unsigned cartnum);
   void clear();
   void clearExternalData();
   void clearTrackData(RDLogLine::TransEdge edge);
