@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdrecording.cpp,v 1.20 2007/02/21 17:24:28 fredg Exp $
+//      $Id: rdrecording.cpp,v 1.24.2.1 2008-11-14 21:30:53 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,18 +21,20 @@
 //
 
 #include <unistd.h>
-#include <rd.h>
-#include <rconf.h>
 
+#include <rd.h>
+#include <rdconf.h>
+#include <rddb.h>
 #include <rdrecording.h>
 #include <rddeck.h>
+#include <rdescape_string.h>
 
 //
 // Global Classes
 //
 RDRecording::RDRecording(int id,bool create)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   if(id<0) {
@@ -45,11 +47,11 @@ RDRecording::RDRecording(int id,bool create)
 
   if(create) {
     sql=QString().sprintf("select ID from RECORDINGS where ID=%d",rec_id);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->size()!=1) {
       delete q;
       sql=QString().sprintf("insert into RECORDINGS set ID=%d",rec_id);
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
     }
     delete q;
   }
@@ -62,546 +64,599 @@ int RDRecording::id() const
 }
 
 
-bool RDRecording::isActive()
+bool RDRecording::isActive() const
 {
-  return RBool(GetStringValue("IS_ACTIVE"));
+  return RDBool(GetStringValue("IS_ACTIVE"));
 }
 
 
-void RDRecording::setIsActive(bool state)
+void RDRecording::setIsActive(bool state) const
 {
-  SetRow("IS_ACTIVE",RYesNo(state));
+  SetRow("IS_ACTIVE",RDYesNo(state));
 }
 
 
-QString RDRecording::station()
+QString RDRecording::station() const
 {
   return GetStringValue("STATION_NAME");
 }
 
 
-void RDRecording::setStation(QString name)
+void RDRecording::setStation(QString name) const
 {
   SetRow("STATION_NAME",name);
 }
 
 
-RDRecording::Type RDRecording::type()
+RDRecording::Type RDRecording::type() const
 {
   return (RDRecording::Type)GetIntValue("TYPE");
 }
 
 
-void RDRecording::setType(RDRecording::Type type)
+void RDRecording::setType(RDRecording::Type type) const
 {
   SetRow("TYPE",(int)type);
 }
 
 
-unsigned RDRecording::channel()
+unsigned RDRecording::channel() const
 {
   return GetUIntValue("CHANNEL");
 }
 
 
-void RDRecording::setChannel(unsigned chan)
+void RDRecording::setChannel(unsigned chan) const
 {
   SetRow("CHANNEL",chan);
 }
 
 
-QTime RDRecording::startTime()
+QTime RDRecording::startTime() const
 {
   return GetTimeValue("START_TIME");
 }
 
 
-void RDRecording::setStartTime(QTime time)
+void RDRecording::setStartTime(QTime time) const
 {
   SetRow("START_TIME",time);
 }
 
 
-QTime RDRecording::endTime()
+QTime RDRecording::endTime() const
 {
   return GetTimeValue("END_TIME");
 }
 
 
-void RDRecording::setEndTime(QTime time)
+void RDRecording::setEndTime(QTime time) const
 {
   SetRow("END_TIME",time);
 }
 
 
-QString RDRecording::cutName()
+QString RDRecording::cutName() const
 {
   return GetStringValue("CUT_NAME");
 }
 
 
-void RDRecording::setCutName(QString name)
+void RDRecording::setCutName(QString name) const
 {
   SetRow("CUT_NAME",name);
 }
 
 
-bool RDRecording::sun()
+bool RDRecording::sun() const
 {
   return GetBoolValue("SUN");
 }
 
 
-void RDRecording::setSun(bool state)
+void RDRecording::setSun(bool state) const
 {
   SetRow("SUN",state);
 }
 
 
-bool RDRecording::mon()
+bool RDRecording::mon() const
 {
   return GetBoolValue("MON");
 }
 
 
-void RDRecording::setMon(bool state)
+void RDRecording::setMon(bool state) const
 {
   SetRow("MON",state);
 }
 
 
-bool RDRecording::tue()
+bool RDRecording::tue() const
 {
   return GetBoolValue("TUE");
 }
 
 
-void RDRecording::setTue(bool state)
+void RDRecording::setTue(bool state) const
 {
   SetRow("TUE",state);
 }
 
 
-bool RDRecording::wed()
+bool RDRecording::wed() const
 {
   return GetBoolValue("WED");
 }
 
 
-void RDRecording::setWed(bool state)
+void RDRecording::setWed(bool state) const
 {
   SetRow("WED",state);
 }
 
 
-bool RDRecording::thu()
+bool RDRecording::thu() const
 {
   return GetBoolValue("THU");
 }
 
 
-void RDRecording::setThu(bool state)
+void RDRecording::setThu(bool state) const
 {
   SetRow("THU",state);
 }
 
 
-bool RDRecording::fri()
+bool RDRecording::fri() const
 {
   return GetBoolValue("FRI");
 }
 
 
-void RDRecording::setFri(bool state)
+void RDRecording::setFri(bool state) const
 {
   SetRow("FRI",state);
 }
 
 
-bool RDRecording::sat()
+bool RDRecording::sat() const
 {
   return GetBoolValue("SAT");
 }
 
 
-void RDRecording::setSat(bool state)
+void RDRecording::setSat(bool state) const
 {
   SetRow("SAT",state);
 }
 
 
-int RDRecording::switchSource()
+int RDRecording::switchSource() const
 {
   return GetIntValue("SWITCH_INPUT");
 }
 
 
-void RDRecording::setSwitchSource(int input)
+void RDRecording::setSwitchSource(int input) const
 {
   SetRow("SWITCH_INPUT",input);
 }
 
 
-int RDRecording::switchDestination()
+int RDRecording::switchDestination() const
 {
   return GetIntValue("SWITCH_OUTPUT");
 }
 
 
-void RDRecording::setSwitchDestination(int output)
+void RDRecording::setSwitchDestination(int output) const
 {
   SetRow("SWITCH_OUTPUT",output);
 }
 
 
-QString RDRecording::description()
+QString RDRecording::description() const
 {
   return GetStringValue("DESCRIPTION");
 }
 
 
-void RDRecording::setDescription(QString string)
+void RDRecording::setDescription(QString string) const
 {
   SetRow("DESCRIPTION",string);
 }
 
 
-unsigned RDRecording::length()
+unsigned RDRecording::length() const
 {
   return GetUIntValue("LENGTH");
 }
 
 
-void RDRecording::setLength(unsigned length)
+void RDRecording::setLength(unsigned length) const
 {
   SetRow("LENGTH",length);
 }
 
 
-int RDRecording::startGpi()
+int RDRecording::startGpi() const
 {
   return GetIntValue("START_GPI");
 }
 
 
-void RDRecording::setStartGpi(int line)
+void RDRecording::setStartGpi(int line) const
 {
   SetRow("START_GPI",line);
 }
 
 
-int RDRecording::endGpi()
+int RDRecording::endGpi() const
 {
   return GetIntValue("END_GPI");
 }
 
 
-void RDRecording::setEndGpi(int line)
+void RDRecording::setEndGpi(int line) const
 {
   SetRow("END_GPI",line);
 }
 
 
-bool RDRecording::allowMultipleRecordings()
+bool RDRecording::allowMultipleRecordings() const
 {
-  return RBool(GetStringValue("ALLOW_MULT_RECS"));
+  return RDBool(GetStringValue("ALLOW_MULT_RECS"));
 }
 
 
-void RDRecording::setAllowMultipleRecordings(bool state)
+void RDRecording::setAllowMultipleRecordings(bool state) const
 {
   SetRow("ALLOW_MULT_RECS",state);
 }
 
 
-unsigned RDRecording::maxGpiRecordingLength()
+unsigned RDRecording::maxGpiRecordingLength() const
 {
   return GetUIntValue("MAX_GPI_REC_LENGTH");
 }
 
 
-void RDRecording::setMaxGpiRecordingLength(unsigned len)
+void RDRecording::setMaxGpiRecordingLength(unsigned len) const
 {
   SetRow("MAX_GPI_REC_LENGTH",len);
 }
 
 
-unsigned RDRecording::trimThreshold()
+unsigned RDRecording::trimThreshold() const
 {
   return GetUIntValue("TRIM_THRESHOLD");
 }
 
 
-void RDRecording::setTrimThreshold(unsigned level)
+void RDRecording::setTrimThreshold(unsigned level) const
 {
   SetRow("TRIM_THRESHOLD",level);
 }
 
 
-unsigned RDRecording::startdateOffset()
+unsigned RDRecording::startdateOffset() const
 {
   return GetUIntValue("STARTDATE_OFFSET");
 }
 
 
-void RDRecording::setStartdateOffset(unsigned offset)
+void RDRecording::setStartdateOffset(unsigned offset) const
 {
   SetRow("STARTDATE_OFFSET",offset);
 }
 
 
-unsigned RDRecording::enddateOffset()
+unsigned RDRecording::enddateOffset() const
 {
   return GetUIntValue("ENDDATE_OFFSET");
 }
 
 
-void RDRecording::setEnddateOffset(unsigned offset)
+void RDRecording::setEnddateOffset(unsigned offset) const
 {
   SetRow("ENDDATE_OFFSET",offset);
 }
 
 
-RDSettings::Format RDRecording::format()
+int RDRecording::eventdateOffset() const
+{
+  return GetIntValue("EVENTDATE_OFFSET");
+}
+
+
+void RDRecording::setEventdateOffset(int offset) const
+{
+  SetRow("EVENTDATE_OFFSET",offset);
+}
+
+
+RDSettings::Format RDRecording::format() const
 {
   return (RDSettings::Format)GetIntValue("FORMAT");
 }
 
 
-void RDRecording::setFormat(RDSettings::Format fmt)
+void RDRecording::setFormat(RDSettings::Format fmt) const
 {
   SetRow("FORMAT",(int)fmt);
 }
 
 
-int RDRecording::channels()
+int RDRecording::channels() const
 {
   return GetIntValue("CHANNELS");
 }
 
 
-void RDRecording::setChannels(int chan)
+void RDRecording::setChannels(int chan) const
 {
   SetRow("CHANNELS",chan);
 }
 
 
-int RDRecording::samprate()
+int RDRecording::samprate() const
 {
   return GetIntValue("SAMPRATE");
 }
 
 
-void RDRecording::setSamprate(int rate)
+void RDRecording::setSamprate(int rate) const
 {
   SetRow("SAMPRATE",rate);
 }
 
 
-int RDRecording::bitrate()
+int RDRecording::bitrate() const
 {
   return GetIntValue("BITRATE");
 }
 
 
-int RDRecording::quality()
+int RDRecording::quality() const
 {
   return GetIntValue("QUALITY");
 }
 
 
-void RDRecording::setQuality(int qual)
+void RDRecording::setQuality(int qual) const
 {
   SetRow("QUALITY",qual);
 }
 
 
-void RDRecording::setBitrate(int rate)
+void RDRecording::setBitrate(int rate) const
 {
   SetRow("BITRATE",rate);
 }
 
 
-int RDRecording::normalizationLevel()
+int RDRecording::normalizationLevel() const
 {
   return GetIntValue("NORMALIZE_LEVEL");
 }
 
 
-void RDRecording::setNormalizationLevel(int level)
+void RDRecording::setNormalizationLevel(int level) const
 {
   SetRow("NORMALIZE_LEVEL",level);
 }
 
 
-int RDRecording::macroCart()
+int RDRecording::macroCart() const
 {
   return GetIntValue("MACRO_CART");
 }
 
 
-void RDRecording::setMacroCart(int cart)
+void RDRecording::setMacroCart(int cart) const
 {
   SetRow("MACRO_CART",cart);
 }
 
 
-bool RDRecording::oneShot()
+bool RDRecording::oneShot() const
 {
   return GetBoolValue("ONE_SHOT");
 }
 
 
-void RDRecording::setOneShot(bool state)
+void RDRecording::setOneShot(bool state) const
 {
   SetRow("ONE_SHOT",state);
 }
 
 
-RDRecording::StartType RDRecording::startType()
+RDRecording::StartType RDRecording::startType() const
 {
   return (RDRecording::StartType)GetUIntValue("START_TYPE");
 }
 
 
-void RDRecording::setStartType(StartType type)
+void RDRecording::setStartType(StartType type) const
 {
   SetRow("START_TYPE",(unsigned)type);
 }
 
 
-RDRecording::EndType RDRecording::endType()
+RDRecording::EndType RDRecording::endType() const
 {
   return (RDRecording::EndType)GetUIntValue("END_TYPE");
 }
 
 
-void RDRecording::setEndType(EndType type)
+void RDRecording::setEndType(EndType type) const
 {
   SetRow("END_TYPE",(unsigned)type);
 }
 
 
-int RDRecording::startMatrix()
+int RDRecording::startMatrix() const
 {
   return GetIntValue("START_MATRIX");
 }
 
 
-void RDRecording::setStartMatrix(int matrix)
+void RDRecording::setStartMatrix(int matrix) const
 {
   SetRow("START_MATRIX",matrix);
 }
 
 
-int RDRecording::startLine()
+int RDRecording::startLine() const
 {
   return GetIntValue("START_LINE");
 }
 
 
-void RDRecording::setStartLine(int line)
+void RDRecording::setStartLine(int line) const
 {
   SetRow("START_LINE",line);
 }
 
 
-int RDRecording::endMatrix()
+int RDRecording::endMatrix() const
 {
   return GetIntValue("END_MATRIX");
 }
 
 
-void RDRecording::setEndMatrix(int matrix)
+void RDRecording::setEndMatrix(int matrix) const
 {
   SetRow("END_MATRIX",matrix);
 }
 
 
-int RDRecording::endLine()
+int RDRecording::endLine() const
 {
   return GetIntValue("END_LINE");
 }
 
 
-void RDRecording::setEndLine(int line)
+void RDRecording::setEndLine(int line) const
 {
   SetRow("END_LINE",line);
 }
 
 
-int RDRecording::startLength()
+int RDRecording::startLength() const
 {
   return GetIntValue("START_LENGTH");
 }
 
 
-void RDRecording::setStartLength(int len)
+void RDRecording::setStartLength(int len) const
 {
   SetRow("START_LENGTH",len);
 }
 
 
-int RDRecording::endLength()
+int RDRecording::endLength() const
 {
   return GetIntValue("END_LENGTH");
 }
 
 
-void RDRecording::setEndLength(int len)
+void RDRecording::setEndLength(int len) const
 {
   SetRow("END_LENGTH",len);
 }
 
 
-int RDRecording::startOffset()
+int RDRecording::startOffset() const
 {
   return GetIntValue("START_OFFSET");
 }
 
 
-void RDRecording::setStartOffset(int offset)
+void RDRecording::setStartOffset(int offset) const
 {
   SetRow("START_OFFSET",offset);
 }
 
 
-QString RDRecording::url()
+QString RDRecording::url() const
 {
   return GetStringValue("URL");
 }
 
 
-void RDRecording::setUrl(QString url)
+void RDRecording::setUrl(QString url) const
 {
   SetRow("URL",url);
 }
 
 
-QString RDRecording::urlUsername()
+QString RDRecording::urlUsername() const
 {
   return GetStringValue("URL_USERNAME");
 }
 
 
-void RDRecording::setUrlUsername(QString name)
+void RDRecording::setUrlUsername(QString name) const
 {
   SetRow("URL_USERNAME",name);
 }
 
 
-QString RDRecording::urlPassword()
+QString RDRecording::urlPassword() const
 {
   return GetStringValue("URL_PASSWORD");
 }
 
 
-void RDRecording::setUrlPassword(QString passwd)
+void RDRecording::setUrlPassword(QString passwd) const
 {
   SetRow("URL_PASSWORD",passwd);
 }
 
 
+int RDRecording::feedId() const
+{
+  return GetIntValue("FEED_ID");
+}
+
+
+void RDRecording::setFeedId(int id) const
+{
+  SetRow("FEED_ID",id);
+}
+
+
+void RDRecording::setFeedId(const QString &keyname) const
+{
+  QString sql=QString().sprintf("select ID from FEEDS where KEY_NAME=\"%s\"",
+				(const char *)keyname);
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  if(q->first()) {
+    setFeedId(q->value(0).toInt());
+  }
+  else {
+    setFeedId(-1);
+  }
+  delete q;
+}
+
+
+QString RDRecording::feedKeyName() const
+{
+  QString ret;
+  QString sql=QString().sprintf("select KEY_NAME from FEEDS where ID=%d",
+				feedId());
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  if(q->first()) {
+    QString ret=q->value(0).toString();
+  }
+  delete q;
+  return ret;
+}
+
+
 QString RDRecording::typeString(RDRecording::Type type)
 {
   QString str;
@@ -636,15 +691,15 @@ QString RDRecording::typeString(RDRecording::Type type)
 }
 
 
-int RDRecording::GetIntValue(QString field)
+int RDRecording::GetIntValue(QString field) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   int accum;
   
   sql=QString().sprintf("select %s from RECORDINGS where ID=%d",
 			(const char *)field,rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     accum=q->value(0).toInt();
     delete q;
@@ -655,15 +710,15 @@ int RDRecording::GetIntValue(QString field)
 }
 
 
-unsigned RDRecording::GetUIntValue(QString field)
+unsigned RDRecording::GetUIntValue(QString field) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   int accum;
   
   sql=QString().sprintf("select %s from RECORDINGS where ID=%d",
 			(const char *)field,rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     accum=q->value(0).toUInt();
     delete q;
@@ -674,17 +729,17 @@ unsigned RDRecording::GetUIntValue(QString field)
 }
 
 
-bool RDRecording::GetBoolValue(QString field)
+bool RDRecording::GetBoolValue(QString field) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   bool state;
 
   sql=QString().sprintf("select %s from RECORDINGS where ID=%d",
 			(const char *)field,rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
-    state=RBool(q->value(0).toString());
+    state=RDBool(q->value(0).toString());
     delete q;
     return state;
   }
@@ -693,15 +748,15 @@ bool RDRecording::GetBoolValue(QString field)
 }
 
 
-QString RDRecording::GetStringValue(QString field)
+QString RDRecording::GetStringValue(QString field) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString accum;
 
   sql=QString().sprintf("select %s from RECORDINGS where ID=%d",
 			(const char *)field,rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     accum=q->value(0).toString();
     delete q;
@@ -712,15 +767,15 @@ QString RDRecording::GetStringValue(QString field)
 }
 
 
-QTime RDRecording::GetTimeValue(QString field)
+QTime RDRecording::GetTimeValue(QString field) const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QTime accum;
 
   sql=QString().sprintf("select %s from RECORDINGS where ID=%d",
 			(const char *)field,rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     accum=q->value(0).toTime();
     delete q;
@@ -731,14 +786,14 @@ QTime RDRecording::GetTimeValue(QString field)
 }
 
 
-int RDRecording::AddRecord()
+int RDRecording::AddRecord() const
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   int n;
 
   sql=QString("select ID from RECORDINGS order by ID desc limit 1");
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     n=q->value(0).toInt()+1;
   }
@@ -747,69 +802,71 @@ int RDRecording::AddRecord()
   }
   delete q;
   sql=QString().sprintf("insert into RECORDINGS set ID=%d",n);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   return n;
 }
 
 
-void RDRecording::SetRow(QString param,int value)
+void RDRecording::SetRow(const QString &param,int value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update RECORDINGS set %s=%d where ID=%d",
 			(const char *)param,value,rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
-void RDRecording::SetRow(QString param,unsigned value)
+void RDRecording::SetRow(const QString &param,unsigned value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update RECORDINGS set %s=%u where ID=%d",
 			(const char *)param,value,rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
-void RDRecording::SetRow(QString param,bool value)
+void RDRecording::SetRow(const QString &param,bool value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update RECORDINGS set %s=\'%s\' where ID=%d",
-			(const char *)param,(const char *)RYesNo(value),
+			(const char *)param,(const char *)RDYesNo(value),
 			rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
-void RDRecording::SetRow(QString param,QString value)
+void RDRecording::SetRow(const QString &param,const QString &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update RECORDINGS set %s=\"%s\" where ID=%d",
-			(const char *)param,(const char *)value,rec_id);
-  q=new QSqlQuery(sql);
+			(const char *)param,
+			(const char *)RDEscapeString(value),
+			rec_id);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
-void RDRecording::SetRow(QString param,QTime value)
+void RDRecording::SetRow(const QString &param,const QTime &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("update RECORDINGS set %s=\"%s\" where ID=%d",
 			(const char *)param,
 			(const char *)value.toString("hh:mm:ss"),rec_id);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
