@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsvc.cpp,v 1.62 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdsvc.cpp,v 1.66.2.3 2008-12-11 19:55:06 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,16 +20,17 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <rdconf.h>
+#include <qmessagebox.h>
 
+#include <rdconf.h>
 #include <rd.h>
 #include <rdsvc.h>
 #include <rddatedecode.h>
 #include <rdcreate_log.h>
 #include <rdclock.h>
 #include <rdlog.h>
-
-#include <qmessagebox.h>
+#include <rddb.h>
+#include <rdescape_string.h>
 
 //
 // Global Classes
@@ -105,6 +106,30 @@ void RDSvc::setAutoRefresh(bool state)
 }
 
 
+int RDSvc::defaultLogShelflife() const
+{
+  return RDGetSqlValue("SERVICES","NAME",svc_name,"DEFAULT_LOG_SHELFLIFE").toInt();
+}
+
+
+void RDSvc::setDefaultLogShelflife(int days) const
+{
+  SetRow("DEFAULT_LOG_SHELFLIFE",days);
+}
+
+
+int RDSvc::elrShelflife() const
+{
+  return RDGetSqlValue("SERVICES","NAME",svc_name,"ELR_SHELFLIFE").toInt();
+}
+
+
+void RDSvc::setElrShelflife(int days) const
+{
+  SetRow("ELR_SHELFLIFE",days);
+}
+
+
 bool RDSvc::chainto() const
 {
   return 
@@ -241,7 +266,7 @@ QString RDSvc::importFilename(ImportSource src,const QDate &date) const
 				(const char *)os_flag,
 				(const char *)svc_name);
   QString ret;
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     ret=RDDateDecode(q->value(0).toString(),date);
   }
@@ -336,8 +361,8 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 		      (const char *)src_str,
 		      (const char *)src_str,
 		      (const char *)src_str,
-		      (const char *)svc_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+		      (const char *)RDEscapeString(svc_name));
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     return false;
@@ -388,8 +413,9 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
     return false;
   }
   sql=QString().sprintf("drop table `%s`",(const char *)dest_table);
-  q=new QSqlQuery(sql);
-  delete q;
+  QSqlQuery *qq;          // Use QSqlQuery so we don't generate a 
+  qq=new QSqlQuery(sql);  // spurious error message.
+  delete qq;
   sql=QString().sprintf("create table `%s` (\
                          ID int primary key,\
                          START_HOUR int not null,\
@@ -408,7 +434,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
                          EVENT_USED enum('N','Y') default 'N',\
                          INDEX START_TIME_IDX (START_HOUR,START_SECS))",
 			(const char *)dest_table);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   //
@@ -488,13 +514,14 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 						  60*minutes_buf.toInt()+
 						  seconds_buf.toInt(),
 						  cartnum,
-						  (const char *)title,
+						  (const char *)
+						  RDEscapeString(title),
 						  cartlen,
 						  (const char *)data_buf,
 						  (const char *)eventid_buf,
 						  (const char *)annctype_buf,
 						  (const char *)cartname);
-			    q=new QSqlQuery(sql);
+			    q=new RDSqlQuery(sql);
 			    delete q;
 			    //
 			    // Insert Break
@@ -514,7 +541,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 					  (const char *)dest_table,line_id-1);
 				
 			      }
-			      q=new QSqlQuery(sql);
+			      q=new RDSqlQuery(sql);
 			      delete q;
 			    }
 			    //
@@ -538,7 +565,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 					  (const char *)track_label,
 					  line_id-1);
 			      }
-			      q=new QSqlQuery(sql);
+			      q=new RDSqlQuery(sql);
 			      delete q;
 			    }
 			    insert_break=false;
@@ -571,7 +598,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 	    break_first=true;
 	    insert_found=true;
 	  }
-	  q=new QSqlQuery(sql);
+	  q=new RDSqlQuery(sql);
 	}
       }
       if(!track_str.isEmpty()) {
@@ -582,7 +609,7 @@ bool RDSvc::import(ImportSource src,const QDate &date,const QString &break_str,
 	    track_first=true;
 	    insert_found=true;
 	  }
-	  q=new QSqlQuery(sql);
+	  q=new RDSqlQuery(sql);
 	}
       }
     }
@@ -600,9 +627,9 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
 			const QString &nextname,QString *report)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   RDClock clock;
-  QString logname_esc=logname;
+  QString logname_esc=RDEscapeString(logname);
   logname_esc.replace(" ","_");
 
   if((!date.isValid()||logname.isEmpty())) {
@@ -614,24 +641,34 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
   //
   // Generate Log Structure
   //
+  QString purge_date;
+  if(defaultLogShelflife()>=0) {
+    purge_date=QDate::currentDate().
+      addDays(defaultLogShelflife()).toString("yyyy-MM-dd");
+  }
   sql=QString().sprintf("select NAME from LOGS where NAME=\"%s\"",
-			(const char *)logname);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(logname));
+  q=new RDSqlQuery(sql);
   if(q->first()) {   // Already Exists
     delete q;
     sql=QString().sprintf("update LOGS set SERVICE=\"%s\",\
                            DESCRIPTION=\"%s log\",ORIGIN_USER=\"%s\",\
                            ORIGIN_DATETIME=now(),LINK_DATETIME=now(),\
                            MODIFIED_DATETIME=now(),START_DATE=null,\
-                           END_DATE=null,NEXT_ID=0 where NAME=\"%s\"",
-			  (const char *)svc_name,
-			  (const char *)svc_name,
-			  "RDLogManager",
-			  (const char *)logname);
-    q=new QSqlQuery(sql);
+                           END_DATE=null,NEXT_ID=0",
+			  (const char *)RDEscapeString(svc_name),
+			  (const char *)RDEscapeString(svc_name),
+			  "RDLogManager");
+    if(!purge_date.isEmpty()) {
+      sql+=(",PURGE_DATE=\""+purge_date+"\"");
+    }
+    sql+=(" where NAME=\""+RDEscapeString(logname)+"\"");
+    printf("SQL: %s\n",(const char *)sql);
+
+    q=new RDSqlQuery(sql);
     delete q;
     sql=QString().sprintf("drop table `%s_LOG`",(const char *)logname_esc);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
   }
   else {             // Doesn't exist
@@ -639,10 +676,13 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
     sql=QString().sprintf("insert into LOGS set NAME=\"%s\",\
                            SERVICE=\"%s\",DESCRIPTION=\"%s log\",\
                            ORIGIN_USER=\"%s\",ORIGIN_DATETIME=now(),\
-                           LINK_DATETIME=now(),MODIFIED_DATETIME=now()",
-			  (const char *)logname,(const char *)svc_name,
-			  (const char *)logname,"RDLogManager");
-    q=new QSqlQuery(sql);
+                           LINK_DATETIME=now(),MODIFIED_DATETIME=now(),\
+                           PURGE_DATE=\"%s\"",
+			  (const char *)RDEscapeString(logname),
+			  (const char *)RDEscapeString(svc_name),
+			  (const char *)RDEscapeString(logname),"RDLogManager",
+			  (const char *)purge_date);
+    q=new RDSqlQuery(sql);
     delete q;
   }
   RDCreateLogTable(QString().sprintf("%s_LOG",(const char *)logname_esc));
@@ -654,8 +694,8 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
   for(int i=0;i<24;i++) {
     sql=QString().sprintf("select CLOCK%d from SERVICES where NAME=\"%s\"",
 			  24*(date.dayOfWeek()-1)+i,
-			  (const char *)svc_name);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(svc_name));
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       if((!q->value(0).isNull())&&(!q->value(0).toString().isEmpty())) {
 	clock.setName(q->value(0).toString());
@@ -673,8 +713,8 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
   //
   int count;
   sql=QString().sprintf("select COUNT from `%s_LOG` order by COUNT desc",
-			(const char *)logname);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(logname));
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     count=q->value(0).toInt()+1;
   }
@@ -689,17 +729,17 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
   if(chainto()) {
     sql=QString().sprintf("insert into `%s_LOG` set ID=%d,COUNT=%d,TYPE=%d,\
                            SOURCE=%d,TRANS_TYPE=%d,LABEL=\"%s\"",
-			  (const char *)logname,count,count,
+			  (const char *)RDEscapeString(logname),count,count,
 			  RDLogLine::Chain,
 			  RDLogLine::Template,
 			  RDLogLine::Segue,
 			  (const char *)nextname);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
     count ++;
   }
 
-  RDLog *log=new RDLog(logname);
+  RDLog *log=new RDLog(RDEscapeString(logname));
   log->updateLinkQuantity(RDLog::SourceMusic);
   log->setLinkState(RDLog::SourceMusic,false);
   log->updateLinkQuantity(RDLog::SourceTraffic);
@@ -716,7 +756,7 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
 		    const QString &logname,QString *report)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString autofill_errors;
 
   emit generationProgress(0);
@@ -734,8 +774,9 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
   // Import File
   //
   QString import_name=
-    QString().sprintf("IMPORT_%s_%s_IMP",(const char *)svc_name,
-		      (const char *)date.toString("yyyyMMdd"));
+      QString().sprintf("IMPORT_%s_%s_IMP",
+			(const char *)RDEscapeStringSQLColumn(svc_name),
+			(const char *)date.toString("yyyyMMdd"));
   import_name.replace(" ","_");
   import(src,date,breakString(),trackString(src),import_name);
 
@@ -815,7 +856,7 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
 			(const char *)import_name,(const char *)import_name,
 			(const char *)import_name,(const char *)import_name,
 			(const char *)import_name,(const char *)import_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     event=true;
     if(q->value(3).toString().isEmpty()) {
@@ -856,7 +897,7 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
   delete dest_event;
   // printf("Import Table: %s\n",(const char *)import_name);
   sql=QString().sprintf("drop table `%s`",(const char *)import_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   return false;
@@ -881,7 +922,7 @@ void RDSvc::clearLogLinks(RDSvc::ImportSource src,const QDate &date,
 	break;
   }
 
-  QString logname_esc=logname+"_LOG";
+  QString logname_esc=RDEscapeString(logname)+"_LOG";
   logname_esc.replace(" ","_");
   RDLogEvent *src_event=new RDLogEvent(logname_esc);
   RDLogEvent *dest_event=new RDLogEvent(logname_esc);
@@ -927,26 +968,27 @@ void RDSvc::clearLogLinks(RDSvc::ImportSource src,const QDate &date,
 void RDSvc::create(const QString exemplar) const
 {
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
 
   if(exemplar.isEmpty()) {  // Create Empty Service
     sql=QString().sprintf("insert into SERVICES set NAME=\"%s\"",
-			  (const char *)svc_name);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(svc_name));
+    q=new RDSqlQuery(sql);
     delete q;
 
     //
     // Create Group Audio Perms
     //
     sql="select NAME from GROUPS";
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into AUDIO_PERMS set\
                            GROUP_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)svc_name);
-      q1=new QSqlQuery(sql);
+			    (const char *)
+			    RDEscapeString(q->value(0).toString()),
+			    (const char *)RDEscapeString(svc_name));
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -955,20 +997,21 @@ void RDSvc::create(const QString exemplar) const
     // Create Station Perms
     //
     sql="select NAME from STATIONS";
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into SERVICE_PERMS set\
                            STATION_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)svc_name);
-      q1=new QSqlQuery(sql);
+			    (const char *)
+			    RDEscapeString(q->value(0).toString()),
+			    (const char *)RDEscapeString(svc_name));
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
   }
   else {    // Base on Existing Service
     sql=QString().sprintf("select NAME_TEMPLATE,CHAIN_LOG,AUTO_REFRESH,\
-                           TFC_PATH,TFC_WIN_PATH,\
+                           ELR_SHELFLIFE,TFC_PATH,TFC_WIN_PATH,\
                            TFC_CART_OFFSET,TFC_CART_LENGTH,\
                            TFC_START_OFFSET,TFC_START_LENGTH,\
                            TFC_LENGTH_OFFSET,TFC_LENGTH_LENGTH,\
@@ -994,11 +1037,11 @@ void RDSvc::create(const QString exemplar) const
     sql=sql.left(sql.length()-1);
     sql+=QString().sprintf(" from SERVICES where NAME=\"%s\"",
 			   (const char *)exemplar);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->first()) {
       sql=QString().sprintf("insert into SERVICES set\
                              NAME_TEMPLATE=\"%s\",CHAIN_LOG=\"%s\",\
-                             AUTO_REFRESH=\"%s\",\
+                             AUTO_REFRESH=\"%s\",ELR_SHELFLIFE=%d,\
                              TFC_PATH=\"%s\",TFC_WIN_PATH=\"%s\",\
                              TFC_CART_OFFSET=%d,TFC_CART_LENGTH=%d,\
                              TFC_START_OFFSET=%d,TFC_START_LENGTH=%d,\
@@ -1020,12 +1063,13 @@ void RDSvc::create(const QString exemplar) const
                              MUS_EVENT_ID_OFFSET=%d,MUS_EVENT_ID_LENGTH=%d,\
                              MUS_ANNC_TYPE_OFFSET=%d,MUS_ANNC_TYPE_LENGTH=%d,\
                              NAME=\"%s\",",
-			    (const char *)q->value(0).toString(),
+			    (const char *)
+			    RDEscapeString(q->value(0).toString()),
 			    (const char *)q->value(1).toString(),
 			    (const char *)q->value(2).toString(),
-			    (const char *)q->value(3).toString(),
+                            q->value(3).toInt(),
 			    (const char *)q->value(4).toString(),
-			    q->value(5).toInt(),
+			    (const char *)q->value(5).toString(),
 			    q->value(6).toInt(),
 			    q->value(7).toInt(),
 			    q->value(8).toInt(),
@@ -1043,9 +1087,9 @@ void RDSvc::create(const QString exemplar) const
 			    q->value(20).toInt(),
 			    q->value(21).toInt(),
 			    q->value(22).toInt(),
-			    (const char *)q->value(23).toString(),
+			    q->value(23).toInt(),
 			    (const char *)q->value(24).toString(),
-			    q->value(25).toInt(),
+			    (const char *)q->value(25).toString(),
 			    q->value(26).toInt(),
 			    q->value(27).toInt(),
 			    q->value(28).toInt(),
@@ -1063,13 +1107,14 @@ void RDSvc::create(const QString exemplar) const
 			    q->value(40).toInt(),
 			    q->value(41).toInt(),
 			    q->value(42).toInt(),
-			    (const char *)svc_name);
+			    q->value(43).toInt(),
+			    (const char *)RDEscapeString(svc_name));
       for(int i=0;i<168;i++) {
 	sql+=QString().sprintf("CLOCK%d=\"%s\",",
-			      i,(const char *)q->value(43+i).toString());
+			      i,(const char *)q->value(44+i).toString());
       }
       sql=sql.left(sql.length()-1);
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
       delete q;
     }
 
@@ -1078,14 +1123,15 @@ void RDSvc::create(const QString exemplar) const
     //
     sql=QString().sprintf("select GROUP_NAME from AUDIO_PERMS\
                            where SERVICE_NAME=\"%s\"",
-			  (const char *)exemplar);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(exemplar));
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into AUDIO_PERMS set\
                              GROUP_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)svc_name);
-      q1=new QSqlQuery(sql);
+			    (const char *)
+			    RDEscapeString(q->value(0).toString()),
+			    (const char *)RDEscapeString(svc_name));
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -1095,14 +1141,15 @@ void RDSvc::create(const QString exemplar) const
     //
     sql=QString().sprintf("select STATION_NAME from SERVICE_PERMS\
                            where SERVICE_NAME=\"%s\"",
-			  (const char *)exemplar);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(exemplar));
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into SERVICE_PERMS set\
                              STATION_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)svc_name);
-      q1=new QSqlQuery(sql);
+			    (const char *)
+			    RDEscapeString(q->value(0).toString()),
+			    (const char *)RDEscapeString(svc_name));
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -1112,14 +1159,14 @@ void RDSvc::create(const QString exemplar) const
     //
     sql=QString().sprintf("select CART_NUMBER from AUTOFILLS\
                            where SERVICE=\"%s\"",
-			  (const char *)exemplar);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(exemplar));
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into AUTOFILLS set\
                              CART_NUMBER=%u,SERVICE=\"%s\"",
 			    q->value(0).toUInt(),
-			    (const char *)svc_name);
-      q1=new QSqlQuery(sql);
+			    (const char *)RDEscapeString(svc_name));
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -1129,14 +1176,15 @@ void RDSvc::create(const QString exemplar) const
     //
     sql=QString().sprintf("select CLOCK_NAME from CLOCK_PERMS\
                            where SERVICE_NAME=\"%s\"",
-			  (const char *)exemplar);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(exemplar));
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into CLOCK_PERMS set\
                              CLOCK_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)svc_name);
-      q1=new QSqlQuery(sql);
+			    (const char *)
+			    RDEscapeString(q->value(0).toString()),
+			    (const char *)RDEscapeString(svc_name));
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -1146,14 +1194,15 @@ void RDSvc::create(const QString exemplar) const
     //
     sql=QString().sprintf("select EVENT_NAME from EVENT_PERMS\
                            where SERVICE_NAME=\"%s\"",
-			  (const char *)exemplar);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(exemplar));
+    q=new RDSqlQuery(sql);
     while(q->next()) {
       sql=QString().sprintf("insert into EVENT_PERMS set\
                              EVENT_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			    (const char *)q->value(0).toString(),
-			    (const char *)svc_name);
-      q1=new QSqlQuery(sql);
+			    (const char *)
+			    RDEscapeString(q->value(0).toString()),
+			    (const char *)RDEscapeString(svc_name));
+      q1=new RDSqlQuery(sql);
       delete q1;
     }
     delete q;
@@ -1163,7 +1212,7 @@ void RDSvc::create(const QString exemplar) const
   // Create Service Reconciliation Table
   //
   sql=RDCreateReconciliationTableSql(svc_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -1171,60 +1220,60 @@ void RDSvc::create(const QString exemplar) const
 void RDSvc::remove() const
 {
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
   QString logname;
 
   sql=QString().sprintf("delete from AUDIO_PERMS where SERVICE_NAME=\"%s\"",
-			(const char *)svc_name);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
   sql=
     QString().sprintf("delete from SERVICE_PERMS where SERVICE_NAME=\"%s\"",
-		      (const char *)svc_name);
-  q=new QSqlQuery(sql);
+		      (const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("update RDAIRPLAY set DEFAULT_SERVICE="" \
                          where DEFAULT_SERVICE=\"%s\"",
-			(const char *)svc_name);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
   sql=
     QString().sprintf("delete from EVENT_PERMS where SERVICE_NAME=\"%s\"",
-		      (const char *)svc_name);
-  q=new QSqlQuery(sql);
+		      (const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
   sql=
     QString().sprintf("delete from CLOCK_PERMS where SERVICE_NAME=\"%s\"",
-		      (const char *)svc_name);
-  q=new QSqlQuery(sql);
+		      (const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
   sql=
     QString().sprintf("delete from AUTOFILLS where SERVICE=\"%s\"",
-		      (const char *)svc_name);
-  q=new QSqlQuery(sql);
+		      (const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
   sql=
     QString().sprintf("delete from REPORT_SERVICES where SERVICE_NAME=\"%s\"",
-		      (const char *)svc_name);
-  q=new QSqlQuery(sql);
+		      (const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from SERVICES where NAME=\"%s\"",
-			(const char *)svc_name);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
 
   sql=QString().sprintf("select NAME from LOGS where SERVICE=\"%s\"",
-			(const char *)svc_name);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     logname=q->value(0).toString();
     logname.replace(" ","_");
     sql=QString().sprintf("drop table `%s_LOG`",(const char *)logname);
-    q1=new QSqlQuery(sql);
+    q1=new RDSqlQuery(sql);
     delete q1;
     sql=QString().sprintf("drop table `%s_REC`",(const char *)logname);
-    q1=new QSqlQuery(sql);
+    q1=new RDSqlQuery(sql);
     delete q1;
   }
   delete q;
@@ -1232,16 +1281,16 @@ void RDSvc::remove() const
   QString tablename=svc_name;
   tablename.replace(" ","_");
   sql=QString().sprintf("drop table `%s_SRT`",(const char *)tablename);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   sql=QString().sprintf("drop table %s_STACK",(const char *)tablename);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   sql=QString().sprintf("delete from LOGS where SERVICE=\"%s\"",
 			(const char *)svc_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -1338,29 +1387,29 @@ QString RDSvc::FieldString(ImportField field) const
 
 void RDSvc::SetRow(const QString &param,QString value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   value.replace("\\","\\\\");  // Needed to preserve Windows pathnames
   sql=QString().sprintf("UPDATE SERVICES SET %s=\"%s\" WHERE NAME=\"%s\"",
 			(const char *)param,
 			(const char *)value,
-			(const char *)svc_name);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDSvc::SetRow(const QString &param,int value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE SERVICES SET %s=%d WHERE NAME=\"%s\"",
 			(const char *)param,
 			value,
-			(const char *)svc_name);
-  q=new QSqlQuery(sql);
+			(const char *)RDEscapeString(svc_name));
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -1377,8 +1426,8 @@ void RDSvc::GetParserStrings(ImportSource src,QString *break_str,
 				(const char *)src_str,
 				(const char *)src_str,
 				(const char *)src_str,
-				(const char *)svc_name);
-  QSqlQuery *q=new QSqlQuery(sql);
+				(const char *)RDEscapeString(svc_name));
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     *break_str=q->value(0).toString();
     *track_str=q->value(1).toString();
