@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_feed.cpp,v 1.4 2007/11/29 19:29:19 fredg Exp $
+//      $Id: edit_feed.cpp,v 1.5 2008-09-26 17:52:23 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -315,25 +315,38 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_autopost_label->setFont(font);
   feed_autopost_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
  
+  //
+  // Audio File Extension
+  //
+  feed_extension_edit=new QLineEdit(this,"feed_extension_edit");
+  feed_extension_edit->setGeometry(155,412,70,19);
+  feed_extension_edit->setMaxLength(16);
+  label=
+    new QLabel(feed_extension_edit,tr("Audio Extension:"),this,
+	       "feed_extension_label");
+  label->setGeometry(20,412,130,19);
+  label->setFont(font);
+  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Maximum Shelf Life
   //
   feed_max_shelf_life_spin=
     new QSpinBox(this,"feed_max_shelf_life_spin");
-  feed_max_shelf_life_spin->setGeometry(155,412,60,19);
+  feed_max_shelf_life_spin->setGeometry(155,434,60,19);
   feed_max_shelf_life_spin->setRange(0,365);
   feed_max_shelf_life_spin->setSpecialValueText(tr("None"));
   QLabel *feed_max_shelf_life_label=
     new QLabel(feed_max_shelf_life_spin,tr("Maximum Shelf Life:"),this,
 	       "feed_max_shelf_life_label");
-  feed_max_shelf_life_label->setGeometry(20,412,130,19);
+  feed_max_shelf_life_label->setGeometry(20,434,130,19);
   feed_max_shelf_life_label->setFont(font);
   feed_max_shelf_life_label->
     setAlignment(AlignRight|AlignVCenter|ShowPrefix);
   QLabel *feed_max_shelf_life_unit=
     new QLabel(feed_max_shelf_life_spin,tr("days"),this,
 	       "feed_max_shelf_life_unit");
-  feed_max_shelf_life_unit->setGeometry(220,412,50,19);
+  feed_max_shelf_life_unit->setGeometry(220,434,50,19);
   feed_max_shelf_life_unit->setFont(font);
   feed_max_shelf_life_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -341,7 +354,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   //  Metadata Button
   //
   button=new QPushButton(this,"edit_button");
-  button->setGeometry(190,439,150,50);
+  button->setGeometry(190,461,150,50);
   button->setDefault(true);
   button->setFont(font);
   button->setText(tr("&Define Auxiliary\nMetadata Fields"));
@@ -438,6 +451,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_settings.setSampleRate(feed_feed->uploadSampleRate());
   feed_settings.setBitRate(feed_feed->uploadBitRate());
   feed_settings.setQuality(feed_feed->uploadQuality());
+  feed_extension_edit->setText(feed_feed->uploadExtension());
   feed_format_edit->setText(feed_settings.description());
   if(feed_feed->normalizeLevel()>0) {
     feed_normalize_box->setChecked(false);
@@ -543,6 +557,7 @@ void EditFeed::okData()
   feed_feed->setUploadSampleRate(feed_settings.sampleRate());
   feed_feed->setUploadBitRate(feed_settings.bitRate());
   feed_feed->setUploadQuality(feed_settings.quality());
+  feed_feed->setUploadExtension(feed_extension_edit->text());
   if(feed_normalize_box->isChecked()) {
     feed_feed->setNormalizeLevel(feed_normalize_spin->value()*1000);
   }
