@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_group.cpp,v 1.22 2007/09/14 14:06:26 fredg Exp $
+//      $Id: edit_group.cpp,v 1.23.2.1 2008-11-30 00:32:58 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,7 +32,7 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
+#include <rddb.h>
 #include <qcolordialog.h>
 
 #include <edit_group.h>
@@ -45,7 +45,7 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // Fix the Window Size
@@ -97,17 +97,31 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   group_description_label->setFont(font);
   group_description_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
+  //
+  // Default Title
+  //
+  group_title_edit=new QLineEdit(this,"group_title_edit");
+  group_title_edit->setGeometry(165,53,sizeHint().width()-175,19);
+  group_title_edit->setMaxLength(255);
+  group_title_edit->setValidator(validator);
+  QLabel *group_title_label=new QLabel(group_title_edit,
+					     tr("Default Import &Title:"),this,
+					     "group_title_label");
+  group_title_label->setGeometry(10,53,150,19);
+  group_title_label->setFont(font);
+  group_title_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Default Cart Type
   //
   group_carttype_box=new QComboBox(this,"group_carttype_box");
-  group_carttype_box->setGeometry(165,53,100,19);
+  group_carttype_box->setGeometry(165,74,100,19);
   group_carttype_box->insertItem(tr("Audio"));
   group_carttype_box->insertItem(tr("Macro"));
   QLabel *group_carttype_label=new QLabel(group_carttype_box,
 					     tr("Default Cart &Type:"),this,
 					     "group_carttype_label");
-  group_carttype_label->setGeometry(10,53,150,19);
+  group_carttype_label->setGeometry(10,74,150,19);
   group_carttype_label->setFont(font);
   group_carttype_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -115,22 +129,22 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   // Default Cart Numbers
   //
   group_lowcart_box=new QSpinBox(this,"group_lowcart_box");
-  group_lowcart_box->setGeometry(165,74,70,19);
+  group_lowcart_box->setGeometry(165,95,70,19);
   group_lowcart_box->setRange(0,999999);
   group_lowcart_box->setSpecialValueText(tr("None"));
   QLabel *label=new QLabel(group_lowcart_box,
 			   tr("Default Cart Number:"),this,
 			   "group_lowcart_label");
-  label->setGeometry(10,74,150,19);
+  label->setGeometry(10,95,150,19);
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
   group_highcart_box=new QSpinBox(this,"group_highcart_box");
-  group_highcart_box->setGeometry(265,74,70,19);
+  group_highcart_box->setGeometry(265,95,70,19);
   group_highcart_box->setRange(1,999999);
   group_highcart_label=new QLabel(group_highcart_box,
 				  tr("to"),this,
 				  "group_highcart_label");
-  group_highcart_label->setGeometry(240,74,20,19);
+  group_highcart_label->setGeometry(240,95,20,19);
   group_highcart_label->setFont(font);
   group_highcart_label->setAlignment(AlignCenter|ShowPrefix);
   connect(group_lowcart_box,SIGNAL(valueChanged(int)),
@@ -140,11 +154,11 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   // Enforce Cart Range Checkbox
   //
   group_enforcerange_box=new QCheckBox(this,"group_enforcerange_box");
-  group_enforcerange_box->setGeometry(20,97,15,15);
+  group_enforcerange_box->setGeometry(20,118,15,15);
   group_enforcerange_label=
     new QLabel(group_enforcerange_box,tr("Enforce Cart Range"),
 	       this,"group_enforcerange_label");
-  group_enforcerange_label->setGeometry(40,95,sizeHint().width()-50,19);
+  group_enforcerange_label->setGeometry(40,118,sizeHint().width()-50,19);
   group_enforcerange_label->setFont(font);
   group_enforcerange_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -152,11 +166,11 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   // Traffic Report Checkbox
   //
   group_traffic_box=new QCheckBox(this,"group_traffic_box");
-  group_traffic_box->setGeometry(20,124,15,15);
+  group_traffic_box->setGeometry(20,145,15,15);
   label=
     new QLabel(group_traffic_box,tr("Include this group in Traffic reports"),
 	       this,"group_traffic_label");
-  label->setGeometry(40,122,sizeHint().width()-50,19);
+  label->setGeometry(40,143,sizeHint().width()-50,19);
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -164,21 +178,43 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   // Music Report Checkbox
   //
   group_music_box=new QCheckBox(this,"group_music_box");
-  group_music_box->setGeometry(20,145,15,15);
+  group_music_box->setGeometry(20,166,15,15);
   label=new QLabel(group_music_box,tr("Include this group in Music reports"),
 		   this,"group_music_label");
-  label->setGeometry(40,143,sizeHint().width()-50,19);
+  label->setGeometry(40,164,sizeHint().width()-50,19);
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
+  //
+  // Cut Autopurging
+  //
+  group_shelflife_box=new QCheckBox(this,"group_shelflife_box");
+  group_shelflife_box->setGeometry(20,193,15,15);
+  connect(group_shelflife_box,SIGNAL(toggled(bool)),
+	  this,SLOT(purgeEnabledData(bool)));
+  group_shelflife_spin=new QSpinBox(this,"group_shelflife_spin");
+  group_shelflife_spin->setGeometry(200,191,40,19);
+  group_shelflife_spin->setRange(0,30);
+  group_shelflife_label=
+    new QLabel(group_shelflife_box,tr("Purge expired cuts after"),
+	       this,"group_shelflife_label");
+  group_shelflife_label->setGeometry(40,193,160,19);
+  group_shelflife_label->setFont(font);
+  group_shelflife_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  group_shelflife_unit=
+    new QLabel(group_shelflife_box,tr("days"),this,"group_shelflife_unit");
+  group_shelflife_unit->setGeometry(250,193,50,19);
+  group_shelflife_unit->setFont(font);
+  group_shelflife_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+
   //
   // Now & Next Data Checkbox
   //
   group_nownext_box=new QCheckBox(this,"group_nownext_box");
-  group_nownext_box->setGeometry(20,182,15,15);
+  group_nownext_box->setGeometry(20,220,15,15);
   label=new QLabel(group_nownext_box,tr("Transmit Now && Next data"),
 		   this,"group_nownext_label");
-  label->setGeometry(40,181,sizeHint().width()-50,19);
+  label->setGeometry(40,219,sizeHint().width()-50,19);
   label->setFont(font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
@@ -186,7 +222,7 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   // Services Selector
   //
   group_svcs_sel=new RDListSelector(this,"group_svcs_sel");
-  group_svcs_sel->setGeometry(10,205,380,130);
+  group_svcs_sel->setGeometry(10,239,380,130);
 
   //
   //  Color Button
@@ -222,6 +258,7 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   //
   group_name_edit->setText(group_group->name());
   group_description_edit->setText(group_group->description());
+  group_title_edit->setText(group_group->defaultTitle());
   group_carttype_box->setCurrentItem(group_group->defaultCartType()-1);
   group_lowcart_box->setValue(group_group->defaultLowCart());
   group_highcart_box->setValue(group_group->defaultHighCart());
@@ -229,18 +266,23 @@ EditGroup::EditGroup(QString group,QWidget *parent,const char *name)
   group_enforcerange_box->setChecked(group_group->enforceCartRange());
   group_traffic_box->setChecked(group_group->exportReport(RDGroup::Traffic));
   group_music_box->setChecked(group_group->exportReport(RDGroup::Music));
+  if(group_group->cutShelflife()>=0) {
+    group_shelflife_spin->setValue(group_group->cutShelflife());
+    group_shelflife_box->setChecked(true);
+  }
+  purgeEnabledData(group_shelflife_box->isChecked());
   group_nownext_box->setChecked(group_group->enableNowNext());
   sql=QString().sprintf("select SERVICE_NAME from AUDIO_PERMS \
                          where GROUP_NAME=\"%s\"",
 			(const char *)group_group->name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     group_svcs_sel->destInsertItem(q->value(0).toString());
   }
   delete q;
 
   sql=QString().sprintf("select NAME from SERVICES");
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     if(group_svcs_sel->destFindItem(q->value(0).toString())==0) {
       group_svcs_sel->sourceInsertItem(q->value(0).toString());
@@ -261,7 +303,7 @@ EditGroup::~EditGroup()
 
 QSize EditGroup::sizeHint() const
 {
-  return QSize(400,407);
+  return QSize(400,450);
 } 
 
 
@@ -302,9 +344,16 @@ void EditGroup::colorData()
 }
 
 
+void EditGroup::purgeEnabledData(bool state)
+{
+  group_shelflife_spin->setEnabled(state);
+  group_shelflife_unit->setEnabled(state);
+}
+
+
 void EditGroup::okData()
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   if(!CheckRange()) {
@@ -312,6 +361,7 @@ void EditGroup::okData()
   }
 
   group_group->setDescription(group_description_edit->text());
+  group_group->setDefaultTitle(group_title_edit->text());
   group_group->
     setDefaultCartType((RDCart::Type)(group_carttype_box->currentItem()+1));
   group_group->setDefaultLowCart(group_lowcart_box->value());
@@ -325,6 +375,12 @@ void EditGroup::okData()
   group_group->
     setExportReport(RDGroup::Traffic,group_traffic_box->isChecked());
   group_group->setExportReport(RDGroup::Music,group_music_box->isChecked());
+  if(group_shelflife_box->isChecked()) {
+    group_group->setCutShelflife(group_shelflife_spin->value());
+  }
+  else {
+    group_group->setCutShelflife(-1);
+  }
   group_group->setEnableNowNext(group_nownext_box->isChecked());
   group_group->setColor(group_color_button->
 			palette().color(QPalette::Active,
@@ -338,14 +394,14 @@ void EditGroup::okData()
 where GROUP_NAME=\"%s\" && SERVICE_NAME=\"%s\"",
 			  (const char *)group_group->name(),
 			  (const char *)group_svcs_sel->destText(i));
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     if(q->size()==0) {
       delete q;
       sql=QString().sprintf("insert into AUDIO_PERMS (GROUP_NAME,SERVICE_NAME) \
 values (\"%s\",\"%s\")",
 			    (const char *)group_group->name(),
 			    (const char *)group_svcs_sel->destText(i));
-      q=new QSqlQuery(sql);
+      q=new RDSqlQuery(sql);
     }
     delete q;
   }
@@ -359,7 +415,7 @@ values (\"%s\",\"%s\")",
     sql+=QString().sprintf(" && SERVICE_NAME<>\"%s\"",
 			   (const char *)group_svcs_sel->destText(i));
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   done(0);
@@ -380,14 +436,14 @@ bool EditGroup::CheckRange()
 
   bool conflict_found=false;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString msg=
     tr("The selected cart range conflicts with the following groups:\n\n");
 
   sql=QString().sprintf("select NAME,DEFAULT_LOW_CART,DEFAULT_HIGH_CART\
                          from GROUPS where NAME!=\"%s\"",
 			(const char *)group_name_edit->text());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     if(((group_lowcart_box->value()<=q->value(1).toInt())&&
 	(group_highcart_box->value()>=q->value(1).toInt()))||
