@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_report.h,v 1.11 2007/02/14 21:51:02 fredg Exp $
+//      $Id: edit_report.h,v 1.12 2007-09-14 14:06:26 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,7 +31,7 @@
 #include <qlabel.h>
 #include <qspinbox.h>
 
-#include <rlistselector.h>
+#include <rdlistselector.h>
 
 #include <rdreport.h>
 
@@ -73,8 +73,8 @@ class EditReport : public QDialog
   QCheckBox *edit_forcetraffic_box;
   QCheckBox *edit_forcemusic_box;
   QComboBox *edit_onairflag_box;
-  RListSelector *edit_service_sel;
-  RListSelector *edit_station_sel;
+  RDListSelector *edit_service_sel;
+  RDListSelector *edit_station_sel;
 };
 
 
