@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_station.cpp,v 1.48 2008-09-18 19:02:11 fredg Exp $
+//      $Id: edit_station.cpp,v 1.48.2.1 2008-11-30 00:32:59 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,6 +35,7 @@
 #include <rdcatch_connect.h>
 #include <rdcart_dialog.h>
 #include <rdtextvalidator.h>
+#include <rdescape_string.h>
 
 #include <edit_station.h>
 #include <edit_rdlibrary.h>
@@ -270,11 +271,22 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   station_hbinterval_unit->setFont(font);
   station_hbinterval_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
+  //
+  // System Maintenance Checkbox
+  //
+  station_maint_box=new QCheckBox(this,"station_maint_box");
+  station_maint_box->setGeometry(10,231,15,15);
+  label=new QLabel(station_maint_box,tr("Include in System Maintenance Pool"),
+		   this,"station_maint_label");
+  label->setGeometry(30,229,sizeHint().width()-40,20);
+  label->setFont(font);
+  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+
   //
   //  RDLibrary Configuration Button
   //
   QPushButton *button=new QPushButton(this,"library_button");
-  button->setGeometry(10,237,80,50);
+  button->setGeometry(10,259,80,50);
   button->setFont(font);
   button->setText(tr("RD&Library"));
   connect(button,SIGNAL(clicked()),this,SLOT(editLibraryData()));
@@ -283,7 +295,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDCatch Configuration Button
   //
   button=new QPushButton(this,"tty_button");
-  button->setGeometry(100,237,80,50);
+  button->setGeometry(100,259,80,50);
   button->setFont(font);
   button->setText(tr("RDCatch"));
   connect(button,SIGNAL(clicked()),this,SLOT(editDeckData()));
@@ -292,7 +304,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDAirPlay Configuration Button
   //
   button=new QPushButton(this,"airplay_button");
-  button->setGeometry(190,237,80,50);
+  button->setGeometry(190,259,80,50);
   button->setFont(font);
   button->setText(tr("RDAirPlay"));
   connect(button,SIGNAL(clicked()),this,SLOT(editAirPlayData()));
@@ -301,7 +313,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDPanel Configuration Button
   //
   button=new QPushButton(this,"rdpanel_button");
-  button->setGeometry(280,237,80,50);
+  button->setGeometry(280,259,80,50);
   button->setFont(font);
   button->setText(tr("RDPanel"));
   connect(button,SIGNAL(clicked()),this,SLOT(editPanelData()));
@@ -310,7 +322,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  RDLogEdit Configuration Button
   //
   button=new QPushButton(this,"logedit_button");
-  button->setGeometry(10,297,80,50);
+  button->setGeometry(10,319,80,50);
   button->setFont(font);
   button->setText(tr("RDLogEdit"));
   connect(button,SIGNAL(clicked()),this,SLOT(editLogEditData()));
@@ -319,7 +331,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Dropboxes Configuration Button
   //
   button=new QPushButton(this,"dropboxes_button");
-  button->setGeometry(100,297,80,50);
+  button->setGeometry(100,319,80,50);
   button->setFont(font);
   button->setText(tr("Dropboxes"));
   connect(button,SIGNAL(clicked()),this,SLOT(editDropboxesData()));
@@ -328,7 +340,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  Switcher Configuration Button
   //
   button=new QPushButton(this,"switcher_button");
-  button->setGeometry(190,297,80,50);
+  button->setGeometry(190,319,80,50);
   button->setFont(font);
   button->setText(tr("Switchers\nGPIO"));
   connect(button,SIGNAL(clicked()),this,SLOT(editSwitcherData()));
@@ -337,7 +349,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  Host Variables Configuration Button
   //
   button=new QPushButton(this,"hostvars_button");
-  button->setGeometry(280,297,80,50);
+  button->setGeometry(280,319,80,50);
   button->setFont(font);
   button->setText(tr("Host\nVariables"));
   connect(button,SIGNAL(clicked()),this,SLOT(editHostvarsData()));
@@ -346,7 +358,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  Audio Ports Configuration Button
   //
   button=new QPushButton(this,"audio_ports_button");
-  button->setGeometry(10,357,80,50);
+  button->setGeometry(10,379,80,50);
   button->setFont(font);
   button->setText(tr("Audio\nPorts"));
   connect(button,SIGNAL(clicked()),this,SLOT(editAudioData()));
@@ -355,7 +367,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  TTY Configuration Button
   //
   button=new QPushButton(this,"tty_button");
-  button->setGeometry(100,357,80,50);
+  button->setGeometry(100,379,80,50);
   button->setFont(font);
   button->setText(tr("Serial\nPorts"));
   connect(button,SIGNAL(clicked()),this,SLOT(editTtyData()));
@@ -364,7 +376,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   //  View Adapters (Audio Resources) Configuration Button
   //
   button=new QPushButton(this,"view_adapters_button");
-  button->setGeometry(190,357,80,50);
+  button->setGeometry(190,379,80,50);
   button->setFont(font);
   button->setText(tr("Audio\nResources"));
   connect(button,SIGNAL(clicked()),this,SLOT(viewAdaptersData()));
@@ -373,7 +385,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Encoders Configuration Button
   //
   button=new QPushButton(this,"encoders_button");
-  button->setGeometry(280,357,80,50);
+  button->setGeometry(280,379,80,50);
   button->setFont(font);
   button->setText(tr("Custom\nEncoders"));
   connect(button,SIGNAL(clicked()),this,SLOT(editEncodersData()));
@@ -382,7 +394,7 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
   // Backups Configuration Button
   //
   button=new QPushButton(this,"backup_button");
-  button->setGeometry(145,417,80,50);
+  button->setGeometry(145,439,80,50);
   button->setFont(font);
   button->setText(tr("Backups"));
   connect(button,SIGNAL(clicked()),this,SLOT(editBackupsData()));
@@ -451,8 +463,8 @@ EditStation::EditStation(QString display,QWidget *parent,const char *name)
       station_filter_box->setChecked(false);
       break;
   }
+  station_maint_box->setChecked(station_station->systemMaint());
   delete q;
-
 }
 
 
@@ -494,7 +506,7 @@ void EditStation::heartbeatClickedData()
 
 QSize EditStation::sizeHint() const
 {
-  return QSize(375,547);
+  return QSize(375,569);
 } 
 
 
@@ -509,7 +521,22 @@ void EditStation::okData()
   QHostAddress addr;
   unsigned cartnum=0;
   bool ok=false;
+  QString sql;
+  RDSqlQuery *q;
 
+  if(!station_maint_box->isChecked()) {
+    sql=QString().sprintf("select NAME from STATIONS where \
+                         (NAME!=\"%s\")&&(SYSTEM_MAINT=\"Y\")",
+			(const char *)RDEscapeString(station_station->name()));
+    q=new RDSqlQuery(sql);
+    if(!q->first()) {
+      QMessageBox::warning(this,tr("System Maintenance"),
+	  tr("At least one host must belong to the system maintenance pool!"));
+      delete q;
+      return;
+    }
+    delete q;
+  }
   if(!addr.setAddress(station_address_edit->text())) {
     QMessageBox::warning(this,tr("Invalid Address"),
 			 tr("The specified IP address is invalid!"));
@@ -552,6 +579,7 @@ void EditStation::okData()
   else {
     station_station->setFilterMode(RDStation::FilterAsynchronous);
   }
+  station_station->setSystemMaint(station_maint_box->isChecked());
   station_catch_connect->reloadHeartbeat();
   station_catch_connect->reloadOffset();
 
