@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_dropboxes.cpp,v 1.4 2007/10/05 13:50:31 fredg Exp $
+//      $Id: list_dropboxes.cpp,v 1.4.2.1 2008-11-29 15:48:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -181,14 +181,19 @@ void ListDropboxes::editData()
 
 void ListDropboxes::deleteData()
 {
+  QString sql;
+  RDSqlQuery *q;
   RDListViewItem *item=(RDListViewItem *)list_dropboxes_view->selectedItem();
   if(item==NULL) {
     return;
   }
+  sql=QString().sprintf("delete from DROPBOX_PATHS where DROPBOX_ID=%d",
+			item->id());
+  q=new RDSqlQuery(sql);
+  delete q;
 
-  QString 
-    sql=QString().sprintf("delete from DROPBOXES where ID=%d",item->id());
-  RDSqlQuery *q=new RDSqlQuery(sql);
+  sql=QString().sprintf("delete from DROPBOXES where ID=%d",item->id());
+  q=new RDSqlQuery(sql);
   delete q;
   delete item;
 }
