@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_stations.cpp,v 1.22 2007/06/12 16:06:11 fredg Exp $
+//      $Id: list_stations.cpp,v 1.25 2008-09-18 19:02:13 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,12 +30,10 @@
 #include <qevent.h>
 #include <qmessagebox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
-#include <rconf.h>
-#include <math.h>
 
 #include <rdairplay_conf.h>
-
+#include <rdescape_string.h>
+#include <rddb.h>
 #include <list_stations.h>
 #include <edit_station.h>
 #include <add_station.h>
@@ -195,10 +193,10 @@ void ListStations::doubleClickedData(QListBoxItem *item)
 void ListStations::RefreshList(QString stationname)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   list_box->clear();
-  q=new QSqlQuery("select NAME from STATIONS",0);
+  q=new RDSqlQuery("select NAME from STATIONS",0);
   while (q->next()) {
     list_box->insertItem(q->value(0).toString());
     if(stationname==list_box->text(list_box->count()-1)) {
@@ -212,88 +210,112 @@ void ListStations::RefreshList(QString stationname)
 void ListStations::DeleteStation(QString name)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
 
   sql=QString().sprintf("delete from DECKS where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from TTYS where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from AUDIO_PORTS where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from RECORDINGS where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=
     QString().sprintf("delete from SERVICE_PERMS where STATION_NAME=\"%s\"",
 		      (const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from RDAIRPLAY where STATION=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from RDPANEL where STATION=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from RDLOGEDIT where STATION=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from MATRICES where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from INPUTS where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from OUTPUTS where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from VGUEST_RESOURCES where\
                            STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from RDLIBRARY where STATION=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from GPIS where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from HOSTVARS where STATION_NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from STATIONS where NAME=\"%s\"",
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=
     QString().sprintf("delete from REPORT_STATIONS where STATION_NAME=\"%s\"",
 		      (const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("delete from PANELS where (TYPE=%d && OWNER=\"%s\")",
 			RDAirPlayConf::StationPanel,
 			(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().
     sprintf("delete from EXTENDED_PANELS where (TYPE=%d && OWNER=\"%s\")",
 	    RDAirPlayConf::StationPanel,(const char *)name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
+  delete q;
+
+  sql=QString().sprintf("select ID from ENCODERS where STATION_NAME=\"%s\"",
+			(const char *)RDEscapeString(name));
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    sql=QString().sprintf("delete from ENCODER_CHANNELS where ENCODER_ID=%d",
+			  q->value(0).toInt());
+    q1=new RDSqlQuery(sql);
+    delete q1;
+    sql=QString().sprintf("delete from ENCODER_SAMPLERATES where ENCODER_ID=%d",
+			  q->value(0).toInt());
+    q1=new RDSqlQuery(sql);
+    delete q1;
+    sql=QString().sprintf("delete from ENCODER_BITRATES where ENCODER_ID=%d",
+			  q->value(0).toInt());
+    q1=new RDSqlQuery(sql);
+    delete q1;
+  }
+  delete q;
+  sql=QString().sprintf("delete from ENCODERS where STATION_NAME=\"%s\"",
+			(const char *)RDEscapeString(name));
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
