@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_macros.cpp,v 1.26 2008-04-02 16:47:25 fredg Exp $
+//      $Id: local_macros.cpp,v 1.26.2.1 2008-12-03 20:24:42 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -766,6 +766,48 @@ void MainWidget::RunLocalMacros(RDMacro *rml)
 	}   
 	break;
 
+      case RDMacro::SN:    // Set default Now & Next Cart
+	if(rml->argQuantity()!=3) {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    rdripc->sendRml(rml);
+	  }
+	  return;
+	}
+	if((rml->arg(0).toString().lower()!="now")&&
+	   (rml->arg(0).toString().lower()!="next")) {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    rdripc->sendRml(rml);
+	  }
+	  return;
+	}
+	if((rml->arg(1).toInt()<1)||(rml->arg(1).toInt()>3)) {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    rdripc->sendRml(rml);
+	  }
+	  return;
+	}
+	if(rml->arg(2).toUInt()>999999) {
+	  if(rml->echoRequested()) {
+	    rml->acknowledge(false);
+	    rdripc->sendRml(rml);
+	  }
+	  return;
+	}
+	if(rml->arg(0).toString().lower()=="now") {
+	  air_log[rml->arg(1).toInt()-1]->setNowCart(rml->arg(2).toUInt());
+	}
+	else {
+	  air_log[rml->arg(1).toInt()-1]->setNextCart(rml->arg(2).toUInt());
+	}
+	if(rml->echoRequested()) {
+	  rml->acknowledge(true);
+	  rdripc->sendRml(rml);
+	}   
+	break;
+
       default:
 	break;
   }
