@@ -2,9 +2,9 @@
 //
 // The On Air Playout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay.cpp,v 1.166 2007/12/31 18:49:09 fredg Exp $
+//      $Id: rdairplay.cpp,v 1.171.2.5 2008-12-03 20:24:42 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -58,6 +58,7 @@
 #include <rdgetpasswd.h>
 #include <rddatedecode.h>
 #include <rddb.h>
+#include <rdescape_string.h>
 
 #include <wall_clock.h>
 #include <globals.h>
@@ -73,10 +74,13 @@ RDRipc *rdripc;
 RDCae *rdcae;
 RDEventPlayer *rdevent_player;
 RDCartDialog *rdcart_dialog;
+RDConfig *air_config;
+MainWidget *prog_ptr;
 
 //
 // Icons
 //
+#include "../icons/rivendell-128x128.xpm"
 #include "../icons/rivendell-22x22.xpm"
 
 //
@@ -84,20 +88,24 @@ RDCartDialog *rdcart_dialog;
 //
 void SigHandler(int signo);
 
-
-void MainWidget::logLine (QString s)
+void MainWidget::logLine(RDConfig::LogPriority prio,const QString &s)
 {
-  LogLine (s);
+  LogLine(prio,s);
 }
 
 MainWidget::MainWidget(QWidget *parent,const char *name)
   :QWidget(parent,name)
 {
+  prog_ptr=this;
   QString str;
   int cards[3];
   int ports[3];
   QString start_rmls[3];
   QString stop_rmls[3];
+  QPixmap *mainmap=NULL;
+  QPixmap *pm=NULL;
+  QPainter *pd=NULL;
+  air_refresh_pixmap=NULL;
 
   //
   // Ensure Single Instance
@@ -111,9 +119,13 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   }
 
   //
-  // Initialize System Logging
+  // Splash Screen
   //
-  openlog("RDAirPlay",0,LOG_USER);
+  air_splash_screen=new QSplashScreen(QPixmap(rivendell_128x128_xpm));
+  air_splash_screen->hide();
+  QTimer *timer=new QTimer(this,"splash_timer");
+  connect(timer,SIGNAL(timeout()),this,SLOT(clearSplashData()));
+  timer->start(AIR_PLAY_SPLASH_TIME,true);
 
   //
   // HACK: Disable the Broken Custom SuSE Dialogs
@@ -217,8 +229,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 			 err);
     exit(0);
   }
-  connect (RDDbStatus(),SIGNAL(logText(QString)),this,SLOT(logLine(QString))); 
-
+  connect (RDDbStatus(),SIGNAL(logText(RDConfig::LogPriority,const QString &)),
+	   this,SLOT(logLine(RDConfig::LogPriority,const QString &))); 
 
   //
   // Master Clock Timer
@@ -243,6 +255,14 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   air_clear_filter=rdairplay_conf->clearFilter();
   air_bar_action=rdairplay_conf->barAction();
   air_editor_cmd=rdstation_conf->editorPath();
+  mainmap=new QPixmap(rdairplay_conf->skinPath());
+  if(mainmap->isNull()||(mainmap->width()<1024)||(mainmap->height()<738)) {
+    delete mainmap;
+    mainmap=NULL;
+  }
+  else {
+    setErasePixmap(*mainmap);
+  }
 
   //
   // Set Audio Assignments
@@ -271,7 +291,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   rduser=NULL;
 
   //
-  // Now & Next Data Transmission Socket
+  // UDP Transmission Socket
   //
   air_nownext_socket=new QSocketDevice(QSocketDevice::Datagram);
 
@@ -284,8 +304,10 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   connect(rename_mapper,SIGNAL(mapped(int)),this,SLOT(logRenamedData(int)));
   QString default_svcname=rdairplay_conf->defaultSvc();
   for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
-    air_log[i]=new LogPlay(rdcae,i,air_nownext_socket);
+    air_log[i]=new LogPlay(rdcae,i,air_nownext_socket,"",&air_plugin_hosts);
     air_log[i]->setDefaultServiceName(default_svcname);
+    air_log[i]->setNowCart(rdairplay_conf->logNowCart(i));
+    air_log[i]->setNextCart(rdairplay_conf->logNextCart(i));
     reload_mapper->setMapping(air_log[i],i);
     connect(air_log[i],SIGNAL(reloaded()),reload_mapper,SLOT(map()));
     rename_mapper->setMapping(air_log[i],i);
@@ -360,12 +382,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   air_post_counter=new PostCounter(this,"air_post_counter");
   air_post_counter->setGeometry(220,5,air_post_counter->sizeHint().width(),
 				air_post_counter->sizeHint().height());
-  air_post_counter->setPostPoint(QTime(),QTime(),0);
- air_post_counter->setFocusPolicy(QWidget::NoFocus);
+  air_post_counter->setPostPoint(QTime(),0,false,false);
+  air_post_counter->setFocusPolicy(QWidget::NoFocus);
   connect(air_master_timer,SIGNAL(timeout()),
 	  air_post_counter,SLOT(tickCounter()));
-  connect(air_log[0],SIGNAL(postPointChanged(QTime,QTime,int)),
-	  air_post_counter,SLOT(setPostPoint(QTime,QTime,int)));
+  connect(air_log[0],SIGNAL(postPointChanged(QTime,int,bool,bool)),
+	  air_post_counter,SLOT(setPostPoint(QTime,int,bool,bool)));
 
   //
   // Pie Counter
@@ -377,7 +399,16 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   air_pie_counter->setCountLength(rdairplay_conf->pieCountLength());
   air_pie_end=rdairplay_conf->pieEndPoint();
   air_pie_counter->setOpMode(air_op_mode);
- air_pie_counter->setFocusPolicy(QWidget::NoFocus);
+  air_pie_counter->setFocusPolicy(QWidget::NoFocus);
+  if(mainmap!=NULL) {
+    pm=new QPixmap(1024,738);
+    pd=new QPainter(pm);
+    pd->drawPixmap(-426,-5,*mainmap);
+    pd->end();
+    air_pie_counter->setErasePixmap(*pm);
+    delete pd;
+    delete pm;
+  }
   connect(air_master_timer,SIGNAL(timeout()),
 	  air_pie_counter,SLOT(tickCounter()));
   connect(rdripc,SIGNAL(onairFlagChanged(bool)),
@@ -506,11 +537,19 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   p.setColor(QColorGroup::Foreground,red);
   air_refresh_label->setPalette(p);
   air_refresh_label->setAlignment(AlignCenter);
+  if(mainmap!=NULL) {
+    air_refresh_pixmap=new QPixmap(1024,738);
+    pd=new QPainter(air_refresh_pixmap);
+    pd->drawPixmap(-390,-sizeHint().height()+65,*mainmap);
+    pd->end();
+    air_refresh_label->setErasePixmap(*air_refresh_pixmap);
+    delete pd;
+  }
 
   //
   // Meter Timer
   //
-  QTimer *timer=new QTimer(this,"meter_timer");
+  timer=new QTimer(this,"meter_timer");
   connect(timer,SIGNAL(timeout()),this,SLOT(meterData()));
   timer->start(RD_METER_UPDATE_INTERVAL);
 
@@ -531,6 +570,15 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     air_panel->setLogfile(air_config->airplayLogname());
     air_panel->setGeometry(510,140,air_panel->sizeHint().width(),
 			 air_panel->sizeHint().height());
+    if(mainmap!=NULL) {
+      pm=new QPixmap(1024,738);
+      pd=new QPainter(pm);
+      pd->drawPixmap(-510,-140,*mainmap);
+      pd->end();
+      air_panel->setErasePixmap(*pm);
+      delete pd;
+      delete pm;
+    }
     air_panel->setPauseEnabled(rdairplay_conf->panelPauseEnabled());
     air_panel->setCard(0,rdairplay_conf->card(2));
     air_panel->setPort(0,rdairplay_conf->port(2));
@@ -614,6 +662,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 	}
       }
     }
+
     air_panel->setSvcName(rdairplay_conf->defaultSvc());
     connect(rdripc,SIGNAL(userChanged()),air_panel,SLOT(changeUser()));
     connect(air_master_timer,SIGNAL(timeout()),air_panel,SLOT(tickClock()));
@@ -685,6 +734,15 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 				this,"air_button_list");
   air_button_list->setGeometry(10,140,air_button_list->sizeHint().width(),
 			       air_button_list->sizeHint().height());
+  if(mainmap!=NULL) {
+    pm=new QPixmap(1024,738);
+    pd=new QPainter(pm);
+    pd->drawPixmap(-10,-140,*mainmap);
+    pd->end();
+    air_button_list->setErasePixmap(*pm);
+    delete pd;
+    delete pm;
+  }
   connect(air_button_list,SIGNAL(selectClicked(int,int,RDLogLine::Status)),
 	  this,SLOT(selectClickedData(int,int,RDLogLine::Status)));
 
@@ -709,7 +767,36 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 	break;
   }	
 
-  LogLine("RDAirPlay started");
+  //
+  // Load Plugins
+  //
+  QString sql;
+  RDSqlQuery *q;
+
+  //
+  // Load Plugins
+  //
+  sql=QString().sprintf("select PLUGIN_PATH,PLUGIN_ARG from NOWNEXT_PLUGINS \
+                         where (STATION_NAME=\"%s\")&&(LOG_MACHINE=0)",
+			(const char *)
+			RDEscapeString(air_config->stationName()));
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    air_plugin_hosts.
+      push_back(new RLMHost(q->value(0).toString(),q->value(1).toString(),
+			    air_nownext_socket,this));
+    LogLine(RDConfig::LogInfo,QString().
+	    sprintf("Loading RLM \"%s\"",
+		    (const char *)q->value(0).toString()));
+    if(!air_plugin_hosts.back()->load()) {
+      LogLine(RDConfig::LogWarning,QString().
+	      sprintf("Failed to load RLM \"%s\"",
+		      (const char *)q->value(0).toString()));
+    }
+  }
+  delete q;
+
+  LogLine(RDConfig::LogInfo,"RDAirPlay started");
 }
 
 
@@ -873,11 +960,17 @@ void MainWidget::logReloadedData(int log)
 	air_log_button[0]->
 	  setText(QString().sprintf("%s\n[%s]",(const char *)str,
 				    (const char *)labelname));
-	LogLine(QString().sprintf("loaded log '%s' in Main Log",
-				  (const char *)air_log[0]->logName().
-				  left(air_log[0]->logName().length()-4)));
+	LogLine(RDConfig::LogInfo,QString().
+		sprintf("loaded log '%s' in Main Log",
+			(const char *)air_log[0]->logName().
+			left(air_log[0]->logName().length()-4)));
 	if(air_log[0]->logName().isEmpty()) {
-	  air_panel->setSvcName(rdairplay_conf->defaultSvc());
+          if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+            air_panel->setSvcName(
+                rduser->serviceCheckDefault( rdairplay_conf->defaultSvc() ) );
+          } else { // RDStation::HostSec
+            air_panel->setSvcName(rdairplay_conf->defaultSvc());
+          }
 	}
 	else {
 	  air_panel->setSvcName(air_log[0]->serviceName());
@@ -889,9 +982,10 @@ void MainWidget::logReloadedData(int log)
 	air_log_button[1]->
 	  setText(QString().sprintf("%s\n[%s]",(const char *)str,
 				    (const char *)labelname));
-	LogLine(QString().sprintf("loaded log '%s' in Aux 1 Log",
-				  (const char *)air_log[1]->logName().
-				  left(air_log[1]->logName().length()-4)));
+	LogLine(RDConfig::LogInfo,QString().
+		sprintf("loaded log '%s' in Aux 1 Log",
+			(const char *)air_log[1]->logName().
+			left(air_log[1]->logName().length()-4)));
 	break;
 	
       case 2:
@@ -899,9 +993,10 @@ void MainWidget::logReloadedData(int log)
 	air_log_button[2]->
 	  setText(QString().sprintf("%s\n[%s]",(const char *)str,
 				    (const char *)labelname));
-	LogLine(QString().sprintf("loaded log '%s' in Aux 2 Log",
-				  (const char *)air_log[2]->logName().
-				  left(air_log[2]->logName().length()-4)));
+	LogLine(RDConfig::LogInfo,QString().
+		sprintf("loaded log '%s' in Aux 2 Log",
+			(const char *)air_log[2]->logName().
+			left(air_log[2]->logName().length()-4)));
 	break;
   }
   SetCaption();
@@ -946,7 +1041,7 @@ void MainWidget::userData()
     delete rduser;
   }
   rduser=new RDUser(rdripc->user());
-  LogLine(QString().
+  LogLine(RDConfig::LogInfo,QString().
 	  sprintf("user changed to '%s'",(const char *)rdripc->user()));
   SetCaption();
 
@@ -967,6 +1062,17 @@ void MainWidget::userData()
     air_log_list[i]->userChanged(add_allowed,delete_allowed,
 				 arrange_allowed,playout_allowed);
   }
+
+  // Update default services for the new user, if applicable.
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+    QString default_svcname = 
+        rduser->serviceCheckDefault( rdairplay_conf->defaultSvc() );
+    for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
+      air_log[i]->setDefaultServiceName(default_svcname);
+    }
+    air_panel->setSvcName(default_svcname);
+  }
+
 }
 
 
@@ -1397,15 +1503,27 @@ void MainWidget::timeModeData(RDAirPlayConf::TimeMode mode)
 void MainWidget::refreshStatusChangedData(bool active)
 {
   if(active) {
+    air_refresh_label->setErasePixmap(QPixmap());
     air_refresh_label->setText(tr("LOG\nREFRESHING"));
   }
   else {
+    if(air_refresh_pixmap!=NULL) {
+      air_refresh_label->setErasePixmap(*air_refresh_pixmap);
+    }
     air_refresh_label->setText("");
   }
   qApp->processEvents();
 }
 
 
+void MainWidget::clearSplashData()
+{
+  air_splash_screen->hide();
+  delete air_splash_screen;
+  air_splash_screen=NULL;
+}
+
+
 void MainWidget::keyPressEvent(QKeyEvent *e)
 {
  switch(e->key()) {
@@ -1462,7 +1580,7 @@ void MainWidget::closeEvent(QCloseEvent *e)
       return;
     }
     rdairplay_conf->setExitCode(RDAirPlayConf::ExitClean);
-    LogLine("RDAirPlay exiting");
+    LogLine(RDConfig::LogInfo,"RDAirPlay exiting");
     air_lock->unlock();
     exit(0);
   }
@@ -1471,8 +1589,14 @@ void MainWidget::closeEvent(QCloseEvent *e)
      QMessageBox::Yes) {
     return;
   }
+  for(unsigned i=0;i<air_plugin_hosts.size();i++) {
+    air_plugin_hosts[i]->unload();
+  }
+  for(int i=0;i<RDAIRPLAY_LOG_QUANTITY;i++) {
+    delete air_log[i];
+  }
   rdairplay_conf->setExitCode(RDAirPlayConf::ExitClean);
-  LogLine("RDAirPlay exiting");
+  LogLine(RDConfig::LogInfo,"RDAirPlay exiting");
   air_lock->unlock();
   exit(0);
 }
@@ -1555,7 +1679,7 @@ void MainWidget::SetManualMode()
   }
   air_button_list->setOpMode(RDAirPlayConf::Manual);
   air_post_counter->setDisabled(true);
-  LogLine("mode set to MANUAL");
+  LogLine(RDConfig::LogInfo,"mode set to MANUAL");
 }
 
 
@@ -1571,7 +1695,7 @@ void MainWidget::SetAutoMode()
   }
   air_button_list->setOpMode(RDAirPlayConf::Auto);
   air_post_counter->setEnabled(true);
-  LogLine("mode set to AUTO");
+  LogLine(RDConfig::LogInfo,"mode set to AUTO");
 }
 
 
@@ -1587,7 +1711,7 @@ void MainWidget::SetLiveAssistMode()
   }
   air_button_list->setOpMode(RDAirPlayConf::LiveAssist); 
   air_post_counter->setDisabled(true);
-  LogLine("mode set to LIVE ASSIST");
+  LogLine(RDConfig::LogInfo,"mode set to LIVE ASSIST");
 }
 
 
@@ -1597,6 +1721,7 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
   int svc_quan=0;
   QString sql;
   RDSqlQuery *q;
+  QStringList services_list;
 
   if(air_action_mode==mode) {
     return;
@@ -1628,14 +1753,25 @@ void MainWidget::SetActionMode(StartButton::Mode mode)
 	  }
 	}
 	if(svc_quan==0) {
-	  sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS\
-                                 where STATION_NAME=\"%s\"",
-				(const char *)rdstation_conf->name());
-	  q=new RDSqlQuery(sql);
-	  while(q->next()&&svc_quan<(RD_MAX_DEFAULT_SERVICES-1)) {
-	    svc_name[svc_quan++]=q->value(0).toString();
-	  }
-	  delete q;
+          if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+            services_list = rduser->services();
+          } else { // RDStation::HostSec
+            sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS \
+                                   where STATION_NAME=\"%s\"",
+                                   (const char *)rdstation_conf->name());
+            q=new RDSqlQuery(sql);
+            while(q->next()) {
+              services_list.append( q->value(0).toString() );
+            }
+            delete q;
+          }
+
+          for ( QStringList::Iterator it = services_list.begin(); 
+                it != services_list.end()&&svc_quan<(RD_MAX_DEFAULT_SERVICES-1);
+                ++it ) {
+            svc_name[svc_quan++]=*it;
+          }
+
 	}
 	/*
 	dialog=new RDCartDialog(&air_add_cart,&air_add_filter,&air_add_group,
@@ -1757,15 +1893,20 @@ int main(int argc,char *argv[])
 	  ".");
   a.installTranslator(&qt);
 
-  QTranslator libradio(0);
-  libradio.load(QString(PREFIX)+QString("/share/srlabs/libradio_")+
-		QTextCodec::locale(),".");
-  a.installTranslator(&libradio);
-
-  QTranslator tests(0);
-  tests.load(QString(PREFIX)+QString("/share/srlabs/rdairplay_")+
+  QTranslator rd(0);
+  rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
 	     QTextCodec::locale(),".");
-  a.installTranslator(&tests);
+  a.installTranslator(&rd);
+
+  QTranslator rdhpi(0);
+  rdhpi.load(QString(PREFIX)+QString("/share/rivendell/librdhpi_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(QString(PREFIX)+QString("/share/rivendell/rdairplay_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&tr);
 
   //
   // Start Event Loop
@@ -1781,10 +1922,12 @@ int main(int argc,char *argv[])
 QString logfile;
 
 
-void LogLine(QString line)
+void LogLine(RDConfig::LogPriority prio,const QString &line)
 {
   FILE *file;
 
+  air_config->log("rdairplay",prio,line);
+
   if(logfile.isEmpty()) {
     return;
   }
