@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_upload.cpp,v 1.15 2008-09-18 19:02:15 fredg Exp $
+//      $Id: edit_upload.cpp,v 1.15.2.2 2008-11-19 16:49:55 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -345,6 +345,23 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   label->setFont(label_font);
   label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
+  //
+  // Event Offset
+  //
+  edit_eventoffset_spin=new QSpinBox(this,"edit_eventoffset_spin");
+  edit_eventoffset_spin->setGeometry(245,313,45,20);
+  edit_eventoffset_spin->setRange(-30,30);
+  label=new QLabel(edit_eventoffset_spin,tr("Event Offset:"),
+		   this,"edit_eventoffset_label");
+  label->setGeometry(140,313,100,20);
+  label->setFont(label_font);
+  label->setAlignment(AlignVCenter|AlignRight);
+  label=new QLabel(edit_eventoffset_spin,tr("days"),
+		   this,"edit_eventoffset_unit");
+  label->setGeometry(295,308,40,20);
+  label->setFont(label_font);
+  label->setAlignment(AlignVCenter|AlignLeft);
+
   //
   //  Save As Button
   //
@@ -403,6 +420,7 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   edit_fri_button->setChecked(edit_recording->fri());
   edit_sat_button->setChecked(edit_recording->sat());
   edit_sun_button->setChecked(edit_recording->sun());
+  edit_eventoffset_spin->setValue(edit_recording->eventdateOffset());
   edit_oneshot_box->setChecked(edit_recording->oneShot());
   edit_settings.setFormat(edit_recording->format());
   edit_settings.setChannels(edit_recording->channels());
@@ -415,7 +433,7 @@ EditUpload::EditUpload(int id,std::vector<int> *adds,QString *filter,
   }
   else {
     edit_normalize_box->setChecked(true);
-    edit_normalize_spin->setValue(edit_recording->normalizationLevel()/1000);
+    edit_normalize_spin->setValue(edit_recording->normalizationLevel()/100);
   }
   normalizeCheckData(edit_normalize_box->isChecked());
   int feed_id=edit_recording->feedId();
@@ -442,7 +460,7 @@ EditUpload::~EditUpload()
 
 QSize EditUpload::sizeHint() const
 {
-  return QSize(520,390);
+  return QSize(520,414);
 } 
 
 
@@ -673,6 +691,7 @@ void EditUpload::Save()
   edit_recording->setFri(edit_fri_button->isChecked());
   edit_recording->setSat(edit_sat_button->isChecked());
   edit_recording->setSun(edit_sun_button->isChecked());
+  edit_recording->setEventdateOffset(edit_eventoffset_spin->value());
   edit_recording->setOneShot(edit_oneshot_box->isChecked());
   edit_recording->setFormat(edit_settings.format());
   edit_recording->setChannels(edit_settings.channels());
@@ -680,7 +699,7 @@ void EditUpload::Save()
   edit_recording->setBitrate(edit_settings.bitRate());
   edit_recording->setQuality(edit_settings.quality());
   if(edit_normalize_box->isChecked()) {
-    edit_recording->setNormalizationLevel(edit_normalize_spin->value()*1000);
+    edit_recording->setNormalizationLevel(edit_normalize_spin->value()*100);
   }
   else {
     edit_recording->setNormalizationLevel(1);
