@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd.h,v 1.49 2007/10/13 16:31:14 dmills Exp $
+//      $Id: rdcatchd.h,v 1.51 2008-10-02 18:52:14 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -51,6 +51,7 @@
 #include <rdmacro_event.h>
 #include <rdconfig.h>
 #include <rdcatch_conf.h>
+#include <rdconfig.h>
 
 #include <catch_event.h>
 
@@ -65,11 +66,12 @@
 #define RDCATCHD_FREE_EVENTS_INTERVAL 1000
 #define RDCATCHD_HEARTBEAT_INTERVAL 10000
 #define RDCATCHD_ERROR_ID_OFFSET 1000000
+extern RDConfig *catch_config;
 
 //
 // Function Prototypes
 //
-void LogLine(QString line);
+void LogLine(RDConfig::LogPriority prio,const QString &line);
 
 
 class MainObject : public QObject
@@ -105,7 +107,8 @@ class MainObject : public QObject
   void sysHeartbeatData();
   void updateXloadsData();
   void startupCartData();
-  void log (QString);
+  void log(RDConfig::LogPriority prio,const QString &line);
+
  private:
   bool StartRecording(int event);
   void StartPlayout(int event);
@@ -151,8 +154,9 @@ class MainObject : public QObject
   void ResolveErrorWildcards(CatchEvent *event,const QString &err_desc,
 			     QString *rml);
   void StartDropboxes();
+  void RunLocalMacros(RDMacro *rml);
+  unsigned GetNextDynamicId();
   bool catch_forked;
-  RDConfig *catch_config;
   QSqlDatabase *catch_db;
   RDStation *catch_rdstation;
   RDRipc *catch_ripc;
