@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdhpisoundcard.cpp,v 1.1 2007/09/14 14:06:53 fredg Exp $
+//    $Id: rdhpisoundcard.cpp,v 1.2.2.1 2008-11-13 14:53:35 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -169,7 +169,7 @@ void RDHPISoundCard::setClockSource(int card,RDHPISoundCard::ClockSource src)
       case RDHPISoundCard::AesEbu:
       case RDHPISoundCard::SpDiff:
 	HPI_SampleClock_SetSource(hpi_subsys,clock_source_control[card],
-				  HPI_SAMPLECLOCK_SOURCE_AESEBU);
+				  HPI_SAMPLECLOCK_SOURCE_AESEBU_SYNC);
 	break;
       case RDHPISoundCard::WordClock:
 	HPI_SampleClock_SetSource(hpi_subsys,clock_source_control[card],
@@ -725,9 +725,9 @@ void RDHPISoundCard::HPIProbe()
       }
     }
     HPI_MixerGetControl(hpi_subsys,hpi_mixer[i],
-			HPI_SAMPLECLOCK_SOURCE,0,
+			HPI_SOURCENODE_CLOCK_SOURCE,0,
 			0,0,
-			HPI_SOURCENODE_CLOCK_SOURCE,
+			HPI_CONTROL_SAMPLECLOCK,
 			&clock_source_control[i]);
     for(int j=0;j<card_input_streams[i];j++) {
       if(HPI_MixerGetControl(hpi_subsys,hpi_mixer[i],  // VOX Controls
