@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary.h,v 1.39 2007/09/14 14:06:56 fredg Exp $
+//      $Id: rdlibrary.h,v 1.43 2008-04-03 16:50:07 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,7 +24,7 @@
 #ifndef RDLIBRARY_H
 #define RDLIBRARY_H
 
-#include <qwidget.h>
+#include <qdialog.h>
 #include <qsize.h>
 #include <qsizepolicy.h>
 #include <qsqldatabase.h>
@@ -34,9 +34,10 @@
 #include <qlabel.h>
 #include <qcheckbox.h>
 #include <qpixmap.h>
+#include <qprogressdialog.h>
 
 #include <rdinstancelock.h>
-
+#include <rdstation.h>
 #include <rdcart.h>
 #include <rduser.h>
 #include <rdripc.h>
@@ -47,6 +48,7 @@
 #include <disk_gauge.h>
 
 #define RDLIBRARY_GEOMETRY_FILE ".rdlibrary"
+#define RDLIBRARY_STEP_SIZE 5000
 
 //
 // Cut Length Deviation Values
@@ -58,7 +60,7 @@
 #define RDLIBRARY_ENFORCE_LENGTH_COLOR blue
 
 
-class MainWidget : public QWidget
+class MainWidget : public QDialog
 {
  Q_OBJECT
  public:
@@ -70,6 +72,7 @@ class MainWidget : public QWidget
   void connectedData(bool state);
   void userData();
   void filterChangedData(const QString &str);
+  void searchClickedData();
   void clearClickedData();
   void groupActivatedData(const QString &str);
   void addData();
@@ -82,19 +85,21 @@ class MainWidget : public QWidget
   void audioChangedData(int state);
   void macroChangedData(int state);
   void quitMainWidget();
-  void RefreshList();
 
  protected:
   void resizeEvent(QResizeEvent *e);
   void closeEvent(QCloseEvent *e);
   
  private:
+  void RefreshList();
   void RefreshLine(RDListViewItem *item);
+  void UpdateItemColor(RDListViewItem *item,RDCart::Validity validity,
+		       const QDateTime &end_datetime,
+		       const QDateTime &current_datetime); 
   void SetCaption(QString user);
   QString GetTypeFilter();
   void LoadGeometry();
   void SaveGeometry();
-  QSqlDatabase *lib_db;
   RDListView *lib_cart_list;
   QString lib_filter_text;
   QString lib_search_text;
@@ -107,6 +112,7 @@ class MainWidget : public QWidget
   QLabel *lib_group_label;
   QComboBox *lib_codes_box;
   QLabel *lib_codes_label;
+  QPushButton *lib_search_button;
   QPushButton *lib_clear_button;
   QPushButton *lib_add_button;
   QPushButton *lib_edit_button;
@@ -122,6 +128,8 @@ class MainWidget : public QWidget
   QString lib_import_path;
   RDInstanceLock *lib_lock;
   QPixmap *lib_rivendell_map;
+  RDStation::FilterMode lib_filter_mode;
+  QProgressDialog *lib_progress_dialog;
 };
 
 
