@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: record_cut.cpp,v 1.84 2007/11/20 16:25:47 fredg Exp $
+//      $Id: record_cut.cpp,v 1.86 2008-08-04 19:05:35 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,7 +32,6 @@
 #include <rd.h>
 #include <rdconf.h>
 #include <rdmixer.h>
-#include <rdtextvalidator.h>
 
 #include <record_cut.h>
 #include <globals.h>
@@ -76,11 +75,6 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   is_closing=false;
   rec_timer_value=0;
 
-  //
-  // Text Validator
-  //
-  RDTextValidator *validator=new RDTextValidator(this,"validator");
-
   //
   // Load Audio Assignments
   //
@@ -137,7 +131,6 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   cut_description_edit=new QLineEdit(this,"cut_description_edit");
   cut_description_edit->setGeometry(10,30,355,19);
   cut_description_edit->setMaxLength(64);
-  cut_description_edit->setValidator(validator);
   QLabel *cut_description_label=new QLabel(cut_description_edit,
 					   tr("&Description"),this,
 					   "cut_description_label");
@@ -151,7 +144,6 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   cut_outcue_edit=new QLineEdit(this,"cut_outcue_edit");
   cut_outcue_edit->setGeometry(10,75,355,19);
   cut_outcue_edit->setMaxLength(64);
-  cut_outcue_edit->setValidator(validator);
   QLabel *cut_outcue_label=new QLabel(cut_outcue_edit,tr("&Outcue"),this,
 				       "cut_outcue_label");
   cut_outcue_label->setGeometry(15,56,120,19);
@@ -764,7 +756,7 @@ void RecordCut::playData()
     rdcae->setPlayPortActive(rec_card_no[1],rec_port_no[1],rec_stream_no[1]);
     rdcae->setOutputVolume(rec_card_no[1],rec_stream_no[1],rec_port_no[1],
            0+rec_cut->playGain());
-    rdcae->play(rec_play_handle,end-start,1000,false);
+    rdcae->play(rec_play_handle,end-start,RD_TIMESCALE_DIVISOR,false);
   }
   if(is_ready&&(!is_recording)) {
     if(rec_mode_box->currentItem()==1) {
