@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_log.cpp,v 1.87 2008-10-21 10:59:41 fredg Exp $
+//      $Id: edit_log.cpp,v 1.87.2.1 2008-12-08 19:00:29 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -41,6 +41,7 @@
 #include <rdlogedit_conf.h>
 #include <rd.h>
 #include <rdconf.h>
+#include <rddatedialog.h>
 
 #include <globals.h>
 #include <add_meta.h>
@@ -193,6 +194,25 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   edit_description_label->setFont(label_font);
   edit_description_label->setAlignment(AlignRight|AlignVCenter);
 
+  //
+  // Purge Date
+  //
+  edit_purgedate_box=new QCheckBox(this,"edit_purgedate_box");
+  edit_purgedate_label=new QLabel(edit_purgedate_box,tr("Delete on"),
+				  this,"edit_purgedate_label");
+  edit_purgedate_label->setFont(label_font);
+  edit_purgedate_label->setAlignment(AlignRight|AlignVCenter);
+  edit_purgedate_edit=new QDateEdit(this,"edit_purgedate_edit");
+  edit_purgedate_button=
+    new QPushButton(tr("Select"),this,"edit_purgedate_button");
+  edit_purgedate_button->setFont(label_font);
+  connect(edit_purgedate_box,SIGNAL(toggled(bool)),
+	  edit_purgedate_edit,SLOT(setEnabled(bool)));
+  connect(edit_purgedate_box,SIGNAL(toggled(bool)),
+	  edit_purgedate_button,SLOT(setEnabled(bool)));
+  connect(edit_purgedate_button,SIGNAL(clicked()),
+	  this,SLOT(selectPurgeDateData()));
+
   //
   // Service
   //
@@ -476,6 +496,16 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   //
   edit_description_edit->setText(edit_log->description());
 
+  QDate purge_date=edit_log->purgeDate();
+  if(purge_date.isNull()) {
+    edit_purgedate_edit->setDate(QDate::currentDate().addMonths(1));
+    edit_purgedate_edit->setDisabled(true);
+    edit_purgedate_button->setDisabled(true);
+  }
+  else {
+    edit_purgedate_box->setChecked(true);
+    edit_purgedate_edit->setDate(purge_date);
+  }
   if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
     services_list = rduser->services();
   } else { // RDStation::HostSec
@@ -486,7 +516,6 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
     }
     delete q;
   }
-
   int n=-1;
   int ncounter=0;
   QString service=edit_log->service();
@@ -502,8 +531,6 @@ EditLog::EditLog(QString logname,vector<RDLogLine> *clipboard,
   if(n>=0) {
     edit_service_box->setCurrentItem(n);
   }
-
-
   if(edit_log->autoRefresh()) {
     edit_autorefresh_box->setCurrentItem(0);
     edit_autorefresh_edit->setText(tr("Yes"));
@@ -598,6 +625,17 @@ void EditLog::descriptionChangedData(const QString &)
 }
 
 
+void EditLog::selectPurgeDateData()
+{
+  QDate date=edit_purgedate_edit->date();
+  RDDateDialog *d=new RDDateDialog(2008,QDate::currentDate().year()+5,this);
+  if(d->exec(&date)==0) {
+    edit_purgedate_edit->setDate(date);
+    edit_changed=true;
+  }
+}
+
+
 void EditLog::serviceActivatedData(const QString &svcname)
 {
   edit_changed=true;
@@ -1145,8 +1183,12 @@ void EditLog::resizeEvent(QResizeEvent *e)
   edit_origin_label_label->setGeometry(size().width()-345,11,40,18);
   edit_track_label->setGeometry(size().width()-425,11,40,18);
   edit_track_label_label->setGeometry(size().width()-510,11,80,18);
-  edit_description_edit->setGeometry(110,40,size().width()-120,20);
+  edit_description_edit->setGeometry(110,40,size().width()-390,20);
   edit_description_label->setGeometry(10,40,95,20);
+  edit_purgedate_box->setGeometry(size().width()-255,42,15,15);
+  edit_purgedate_label->setGeometry(size().width()-240,40,60,20);
+  edit_purgedate_edit->setGeometry(size().width()-170,40,100,20);
+  edit_purgedate_button->setGeometry(size().width()-60,37,50,26);
   edit_service_box->setGeometry(110,68,120,22);
   edit_service_edit->setGeometry(110,68,120,22);
   edit_service_label->setGeometry(10,68,95,22);
@@ -1218,6 +1260,12 @@ void EditLog::paintEvent(QPaintEvent *e)
 void EditLog::SaveLog()
 {
   edit_log->setDescription(edit_description_edit->text());
+  if(edit_purgedate_box->isChecked()) {
+    edit_log->setPurgeDate(edit_purgedate_edit->date());
+  }
+  else {
+    edit_log->setPurgeDate(QDate());
+  }
   edit_log->setService(edit_service_box->currentText());
   if(edit_startdate_box->isChecked()) {
     edit_log->setStartDate(edit_startdate_edit->date());
