@@ -2,9 +2,9 @@
 //
 // The User Login/Logout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogin.cpp,v 1.30 2008-07-26 00:01:39 fredg Exp $
+//      $Id: rdlogin.cpp,v 1.30.2.1 2008-12-09 15:45:23 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -52,6 +52,8 @@
 MainWidget::MainWidget(QWidget *parent,const char *name)
   :QDialog(parent,name)
 {
+  login_user_width=160;
+
   QString str;
   QString sql;
   RDSqlQuery *q;
@@ -71,7 +73,6 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Fix the Window Size
   //
   setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
@@ -143,28 +144,32 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // User Label
   //
   login_label=new QLabel(this,"login_label");
-  login_label->setGeometry(10,10,260,21);
   login_label->setFont(label_font);
-  login_label->setAlignment(AlignHCenter);
+  login_label->setAlignment(AlignCenter);
   login_label->setText(tr("Current User: unknown"));
 
   //
   // User Name
   //
   login_username_box=new QComboBox(this,"login_username_box");
-  login_username_box->setGeometry(120,40,120,19);
   login_username_box->setFont(line_edit_font);
   login_username_box->setFocus();
+  QFontMetrics fm(line_edit_font);
   sql="select LOGIN_NAME from USERS where ADMIN_CONFIG_PRIV=\"N\"\
        order by LOGIN_NAME";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     login_username_box->insertItem(q->value(0).toString());
+    if(fm.width(q->value(0).toString())>login_user_width) {
+      login_user_width=fm.width(q->value(0).toString());
+    }
   }
   delete q;
-  QLabel *login_username_label=new QLabel(login_username_box,tr("&Username:"),
-					  this,"login_username_label");
-  login_username_label->setGeometry(20,40,85,19);
+  if(login_user_width>900) {
+    login_user_width=900;
+  }
+  login_username_label=new QLabel(login_username_box,tr("&Username:"),
+				  this,"login_username_label");
   login_username_label->setFont(small_label_font);
   login_username_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
@@ -172,22 +177,19 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Password
   //
   login_password_edit=new QLineEdit(this,"login_password_edit");
-  login_password_edit->setGeometry(120,61,120,19);
   login_password_edit->setFont(line_edit_font);
   login_password_edit->setMaxLength(16);
   login_password_edit->setValidator(validator);
   login_password_edit->setEchoMode(QLineEdit::Password);
-  QLabel *login_password_label=new QLabel(login_password_edit,tr("&Password:"),
-					  this,"login_password_label");
-  login_password_label->setGeometry(20,61,85,19);
+  login_password_label=new QLabel(login_password_edit,tr("&Password:"),
+				  this,"login_password_label");
   login_password_label->setFont(small_label_font);
   login_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Login Button
   //
-  QPushButton *login_button=new QPushButton(this,"login_button");
-  login_button->setGeometry(10,100,80,50);
+  login_button=new QPushButton(this,"login_button");
   login_button->setDefault(true);
   login_button->setFont(button_font);
   login_button->setText(tr("&Set User"));
@@ -196,8 +198,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Logout Button
   //
-  QPushButton *logout_button=new QPushButton(this,"logout_button");
-  logout_button->setGeometry(100,100,80,50);
+  logout_button=new QPushButton(this,"logout_button");
   logout_button->setFont(button_font);
   logout_button->setText(tr("&Default\nUser"));
   connect(logout_button,SIGNAL(clicked()),this,SLOT(logoutData()));
@@ -205,11 +206,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Cancel Button
   //
-  QPushButton *cancel_button=new QPushButton(this,"cancel_button");
-  cancel_button->setGeometry(190,100,80,50);
+  cancel_button=new QPushButton(this,"cancel_button");
   cancel_button->setFont(button_font);
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
+
+  resizeEvent(NULL);
 }
 
 
@@ -226,7 +228,7 @@ MainWidget::~MainWidget()
 
 QSize MainWidget::sizeHint() const
 {
-  return QSize(280,160);
+  return QSize(120+login_user_width,160);
 }
 
 
@@ -248,6 +250,7 @@ void MainWidget::userData()
   str=QString(tr("Current User:"));
   login_label->setText(QString().sprintf("%s %s",(const char *)str,
 					 (const char *)login_ripc->user()));
+  resizeEvent(NULL);
 }
 
 
@@ -297,6 +300,19 @@ void MainWidget::quitMainWidget()
 }
 
 
+void MainWidget::resizeEvent(QResizeEvent *e)
+{
+  login_label->setGeometry(0,10,size().width(),21);
+  login_username_box->setGeometry(110,40,size().width()-120,19);
+  login_username_label->setGeometry(10,40,85,19);
+  login_password_edit->setGeometry(110,61,size().width()-120,19);
+  login_password_label->setGeometry(10,61,85,19);
+  login_button->setGeometry(size().width()-270,size().height()-60,80,50);
+  logout_button->setGeometry(size().width()-180,size().height()-60,80,50);
+  cancel_button->setGeometry(size().width()-90,size().height()-60,80,50);
+}
+
+
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv);
