@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_clock.cpp,v 1.22.2.1 2008-10-24 12:12:38 fredg Exp $
+//      $Id: edit_clock.cpp,v 1.22.2.2 2008-11-30 00:33:00 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -101,7 +101,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   // Clock List
   //
   edit_clocks_list=new ClockListView(this,"edit_clocks_list");
-  edit_clocks_list->setGeometry(10,35,CENTER_LINE-20,sizeHint().height()-100);
+  edit_clocks_list->setGeometry(10,35,CENTER_LINE-20,sizeHint().height()-250);
   edit_clocks_list->setAllColumnsShowFocus(true);
   edit_clocks_list->setItemMargin(5);
   edit_clocks_list->addColumn(tr("Start"));
@@ -123,7 +123,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //  Add Button
   //
   QPushButton *button=new QPushButton(this,"add_button");
-  button->setGeometry(70,sizeHint().height()-60,80,50);
+  button->setGeometry(70,sizeHint().height()-210,80,50);
   button->setFont(bold_font);
   button->setText(tr("&Add"));
   connect(button,SIGNAL(clicked()),this,SLOT(addData()));
@@ -132,7 +132,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //  Edit Button
   //
   button=new QPushButton(this,"edit_button");
-  button->setGeometry(160,sizeHint().height()-60,80,50);
+  button->setGeometry(160,sizeHint().height()-210,80,50);
   button->setFont(bold_font);
   button->setText(tr("&Edit"));
   connect(button,SIGNAL(clicked()),this,SLOT(editData()));
@@ -141,16 +141,27 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //  Delete Button
   //
   button=new QPushButton(this,"delete_button");
-  button->setGeometry(250,sizeHint().height()-60,80,50);
+  button->setGeometry(250,sizeHint().height()-210,80,50);
   button->setFont(bold_font);
   button->setText(tr("&Delete"));
   connect(button,SIGNAL(clicked()),this,SLOT(deleteData()));
 
+  //
+  // Remarks
+  //
+  edit_remarks_edit=new QTextEdit(this,"edit_remarks_edit");
+  edit_remarks_edit->setGeometry(10,sizeHint().height()-140,CENTER_LINE-20,130);
+  edit_remarks_edit->setTextFormat(QTextEdit::PlainText);
+  label=new QLabel(edit_remarks_edit,tr("Remarks"),this,"edit_remarks_label");
+  label->setGeometry(15,sizeHint().height()-155,CENTER_LINE-20,15);
+  label->setFont(bold_font);
+  label->setAlignment(AlignLeft|AlignVCenter);
+
   //
   //  Scheduler-Rules button
   //
   button=new QPushButton(this,"schedrules_button");
-  button->setGeometry(CENTER_LINE-50,sizeHint().height()-60,80,50);
+  button->setGeometry(CENTER_LINE+20,sizeHint().height()-60,70,50);
   button->setFont(bold_font);
   button->setText(tr("Scheduler\nRules"));
   connect(button,SIGNAL(clicked()),this,SLOT(schedRules()));
@@ -159,7 +170,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //  Save Button
   //
   button=new QPushButton(this,"save_button");
-  button->setGeometry(CENTER_LINE+50,sizeHint().height()-60,80,50);
+  button->setGeometry(CENTER_LINE+110,sizeHint().height()-60,70,50);
   button->setFont(bold_font);
   button->setText(tr("&Save"));
   connect(button,SIGNAL(clicked()),this,SLOT(saveData()));
@@ -168,7 +179,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //  Save As Button
   //
   button=new QPushButton(this,"saveas_button");
-  button->setGeometry(CENTER_LINE+140,sizeHint().height()-60,80,50);
+  button->setGeometry(CENTER_LINE+190,sizeHint().height()-60,70,50);
   button->setFont(bold_font);
   button->setText(tr("Save &As"));
   connect(button,SIGNAL(clicked()),this,SLOT(saveAsData()));
@@ -177,8 +188,8 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //  Service Associations Button
   //
   button=new QPushButton(this,"svc_button");
-  button->setGeometry(CENTER_LINE+(sizeHint().width()-CENTER_LINE)/2-85,
-		      sizeHint().height()-60,80,50);
+  button->setGeometry(CENTER_LINE+(sizeHint().width()-CENTER_LINE)/2-25,
+		      sizeHint().height()-60,70,50);
   button->setFont(bold_font);
   button->setText(tr("&Services\nList"));
   connect(button,SIGNAL(clicked()),this,SLOT(svcData()));
@@ -188,8 +199,8 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //
   edit_color_button=new QPushButton(this,"edit_color_button");
   edit_color_button->
-    setGeometry(CENTER_LINE+(sizeHint().width()-CENTER_LINE)/2+5,
-		sizeHint().height()-60,80,50);
+    setGeometry(CENTER_LINE+(sizeHint().width()-CENTER_LINE)/2+55,
+		sizeHint().height()-60,70,50);
   edit_color_button->setFont(bold_font);
   edit_color_button->setText(tr("Colo&r"));
   connect(edit_color_button,SIGNAL(clicked()),this,SLOT(colorData()));
@@ -206,7 +217,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //  OK Button
   //
   button=new QPushButton(this,"ok_button");
-  button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
+  button->setGeometry(sizeHint().width()-160,sizeHint().height()-60,70,50);
   button->setDefault(true);
   button->setFont(bold_font);
   button->setText(tr("&OK"));
@@ -216,7 +227,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //  Cancel Button
   //
   button=new QPushButton(this,"cancel_button");
-  button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
+  button->setGeometry(sizeHint().width()-80,sizeHint().height()-60,70,50);
   button->setFont(bold_font);
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
@@ -233,6 +244,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
     edit_color_button->
       setPalette(QPalette(edit_clock->color(),backgroundColor()));
   }
+  edit_remarks_edit->setText(edit_clock->remarks());
   edit_modified=false;
   RefreshList();
 }
@@ -344,7 +356,6 @@ void EditClock::deleteData()
 }
 
 
-///////////////////////////////////////
 void EditClock::schedRules()
 {
   unsigned edit_artistsep = edit_clock->getArtistSep();
@@ -368,7 +379,6 @@ void EditClock::schedRules()
 
   delete dialog;
 }
-////////////////////////////////////////
 
 
 void EditClock::svcData()
@@ -544,7 +554,7 @@ void EditClock::paintEvent(QPaintEvent *e)
   QPainter *p=new QPainter(this);
   p->setPen(QColor(black));
   p->moveTo(CENTER_LINE,10);
-  p->lineTo(CENTER_LINE,sizeHint().height()-65);
+  p->lineTo(CENTER_LINE,sizeHint().height()-10);
 
   p->end();
 }
@@ -560,6 +570,7 @@ void EditClock::Save()
 {
   edit_clock->setColor(edit_color_button->backgroundColor());
   edit_clock->setShortName(edit_shortname_edit->text());
+  edit_clock->setRemarks(edit_remarks_edit->text());
   edit_clock->save();
   if(edit_clock->getRulesModified())
      {
