@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_clock.h,v 1.10 2007/03/12 11:57:05 fredg Exp $
+//      $Id: edit_clock.h,v 1.11.2.1 2008-11-30 00:33:00 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,12 +30,13 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qcombobox.h>
-#include <schedruleslist.h>
 #include <qvariant.h>
+#include <qtextedit.h>
 
 #include <rdclock.h>
 
 #include <clock_listview.h>
+#include <schedruleslist.h>
 
 //
 // Layout
@@ -95,6 +96,7 @@ class EditClock : public QDialog
   bool edit_new_clock;
   std::vector<QString> *edit_new_clocks;
   SchedRulesList* sched_rules_list;
+  QTextEdit *edit_remarks_edit;
 };
 
 
