@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: ripcd.cpp,v 1.64 2008-09-30 18:19:44 fredg Exp $
+//      $Id: ripcd.cpp,v 1.64.2.4 2008-12-08 16:44:20 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -237,9 +237,10 @@ MainObject::MainObject(QObject *parent,const char *name)
   srandom(QTime::currentTime().msec());
   ripcd_maint_timer=new QTimer(this,"ripcd_maint_timer");
   connect(ripcd_maint_timer,SIGNAL(timeout()),this,SLOT(checkMaintData()));
-  ripcd_maint_timer->start(GetMaintInterval());
+  int interval=GetMaintInterval();
+  ripcd_maint_timer->start(interval);
 
-  LogLine(RDConfig::LogInfo,"ripcd started");
+  LogLine(RDConfig::LogInfo,"started");
 }
 
 
@@ -360,8 +361,17 @@ void MainObject::checkMaintData()
     QDateTime(QDate::currentDate(),QTime::currentTime());
   bool run=false;
 
+  RunLocalMaintRoutine();
+
   //
-  // Get the maintenance timestamp
+  // Should we try to run system maintenance?
+  //
+  if(!rdstation->systemMaint()) {
+    return;
+  }
+
+  //
+  // Get the system-wide maintenance timestamp
   //
   sql="lock tables VERSION write";
   q=new RDSqlQuery(sql);
@@ -371,7 +381,7 @@ void MainObject::checkMaintData()
   if(q->first()) {
     run=1000*q->value(0).toDateTime().secsTo(current_datetime)>
       RD_MAINT_MAX_INTERVAL;
-}
+  }
   delete q;
   sql="unlock tables";
   q=new RDSqlQuery(sql);
@@ -381,7 +391,7 @@ void MainObject::checkMaintData()
   // Run the routines
   //
   if(run) {
-    RunMaintRoutine();
+    RunSystemMaintRoutine();
   }
 }
 
@@ -708,31 +718,36 @@ void MainObject::LoadGpiTable()
 {
   for(int i=0;i<MAX_MATRICES;i++) {
     for(int j=0;j<MAX_GPIO_PINS;j++) {
-      ripcd_gpi_macro[i][j]=-1;
-      ripcd_gpo_macro[i][j]=-1;
       ripcd_gpi_mask[i][j]=true;
       ripcd_gpo_mask[i][j]=true;
-      ripcd_gpi_polarity[i][j]=false;
-      ripcd_gpo_polarity[i][j]=false;
+      for(int k=0;k<2;k++) {
+	ripcd_gpi_macro[i][j][k]=0;
+	ripcd_gpo_macro[i][j][k]=0;
+      }
     }
   }
-  QString sql=QString().sprintf("select MATRIX,NUMBER,MACRO_CART from GPIS \
+  QString sql=QString().sprintf("select MATRIX,NUMBER,OFF_MACRO_CART,\
+                                 MACRO_CART from GPIS \
                                  where STATION_NAME=\"%s\"",
 				(const char *)ripcd_config->stationName());
   RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
-    ripcd_gpi_macro[q->value(0).toInt()][q->value(1).toInt()-1]=
+    ripcd_gpi_macro[q->value(0).toInt()][q->value(1).toInt()-1][0]=
       q->value(2).toInt();
+    ripcd_gpi_macro[q->value(0).toInt()][q->value(1).toInt()-1][1]=
+      q->value(3).toInt();
   }
   delete q;
 
-  sql=QString().sprintf("select MATRIX,NUMBER,MACRO_CART from GPOS \
-                         where STATION_NAME=\"%s\"",
+  sql=QString().sprintf("select MATRIX,NUMBER,OFF_MACRO_CART,MACRO_CART \
+                         from GPOS where STATION_NAME=\"%s\"",
 			(const char *)ripcd_config->stationName());
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    ripcd_gpo_macro[q->value(0).toInt()][q->value(1).toInt()-1]=
+    ripcd_gpo_macro[q->value(0).toInt()][q->value(1).toInt()-1][0]=
       q->value(2).toInt();
+    ripcd_gpo_macro[q->value(0).toInt()][q->value(1).toInt()-1][1]=
+      q->value(3).toInt();
   }
   delete q;
 }
@@ -795,8 +810,9 @@ void MainObject::SendGpoMask(int ch,int matrix)
 void MainObject::SendGpiCart(int ch,int matrix)
 {
   for(int i=0;i<ripcd_gpis[matrix];i++) {
-    EchoCommand(ch,QString().sprintf("GC %d %d %d!",
-				     matrix,i,ripcd_gpi_macro[matrix][i]));
+    EchoCommand(ch,QString().sprintf("GC %d %d %d %d!",
+				     matrix,i,ripcd_gpi_macro[matrix][i][0],
+				     ripcd_gpi_macro[matrix][i][1]));
   }
 }
 
@@ -804,8 +820,9 @@ void MainObject::SendGpiCart(int ch,int matrix)
 void MainObject::SendGpoCart(int ch,int matrix)
 {
   for(int i=0;i<ripcd_gpos[matrix];i++) {
-    EchoCommand(ch,QString().sprintf("GD %d %d %d!",
-				     matrix,i,ripcd_gpo_macro[matrix][i]));
+    EchoCommand(ch,QString().sprintf("GD %d %d %d %d!",
+				     matrix,i,ripcd_gpo_macro[matrix][i][0],
+				     ripcd_gpo_macro[matrix][i][1]));
   }
 }
 
@@ -846,28 +863,6 @@ void QApplication::saveState(QSessionManager &sm) {
 };
 
 
-void MainObject::RunMaintRoutine()
-{
-  //
-  // Purge Expired Podcasts
-  //
-  if(fork()==0) {
-    system("rdpurgecasts");
-    exit(0);
-  }
-
-  LogLine(RDConfig::LogInfo,"ran maintenance routines");
-}
-
-
-int MainObject::GetMaintInterval() const
-{
-  return (int)(RD_MAINT_MIN_INTERVAL+
-	       (RD_MAINT_MAX_INTERVAL-RD_MAINT_MIN_INTERVAL)*
-	       (double)random()/(double)RAND_MAX);
-}
-
-
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv,false);
