@@ -5,7 +5,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: sas64000gpi.cpp,v 1.5 2007/09/14 14:06:59 fredg Exp $
+//      $Id: sas64000gpi.cpp,v 1.8 2008-10-01 13:10:15 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,6 +33,7 @@ Sas64000Gpi::Sas64000Gpi(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Get Matrix Parameters
   //
+  sas_matrix=matrix->matrix();
   sas_inputs=matrix->inputs();
   sas_outputs=matrix->outputs();
   sas_gpis=matrix->gpis();
@@ -41,7 +42,7 @@ Sas64000Gpi::Sas64000Gpi(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port());
+  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
   sas_device=new RDTTYDevice();
   if(tty->active()) {
     sas_device->setName(tty->port());
@@ -51,6 +52,13 @@ Sas64000Gpi::Sas64000Gpi(RDMatrix *matrix,QObject *parent,const char *name)
     sas_device->open(IO_Raw|IO_ReadWrite);
   }
   delete tty;
+
+  //
+  // Interval OneShots
+  //
+  sas_gpo_oneshot=new RDOneShot(this);
+  connect(sas_gpo_oneshot,SIGNAL(timeout(void *)),
+	  this,SLOT(gpoOneshotData(void*)));
 }
 
 
@@ -86,28 +94,33 @@ void Sas64000Gpi::processCommand(RDMacro *cmd)
 	break;
 
       case RDMacro::GO:
-	if((cmd->arg(1).toInt()<1)||(cmd->arg(1).toInt()>sas_gpos)) {
+	if((cmd->arg(1).toString().lower()!="o")||
+	   (cmd->arg(2).toInt()<1)||(cmd->arg(2).toInt()>sas_gpos)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
 	  return;
 	}
-	if(cmd->arg(3).toInt()==0) {   // Latch
-	  if(cmd->arg(2).toInt()==0) {   // Off
+	if(cmd->arg(4).toInt()==0) {   // Latch
+	  if(cmd->arg(3).toInt()==0) {   // Off
 	    cmd_byte=0xF9;
+	    emit gpoChanged(sas_matrix,cmd->arg(2).toInt()-1,false);
 	  }
 	  else {
 	    cmd_byte=0xFA;
+	    emit gpoChanged(sas_matrix,cmd->arg(2).toInt()-1,true);
 	  }
 	}
-	else {
-	  if(cmd->arg(2).toInt()==0) {
+	else {  // Pulse
+	  if(cmd->arg(3).toInt()==0) {
 	    cmd->acknowledge(false);
 	    emit rmlEcho(cmd);
 	    return;
 	  }
 	  cmd_byte=0xFB;
+	  sas_gpo_oneshot->start((void *)(cmd->arg(2).toInt()-1),500);
+	  emit gpoChanged(sas_matrix,cmd->arg(2).toInt()-1,true);
 	}
-	sprintf(str,"%c%c\xFF",cmd_byte,cmd->arg(1).toInt()-1);
+	sprintf(str,"%c%c\xFF",cmd_byte,cmd->arg(2).toInt()-1);
 	sas_device->writeBlock(str,3);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
@@ -121,6 +134,7 @@ void Sas64000Gpi::processCommand(RDMacro *cmd)
 }
 
 
-void Sas64000Gpi::processStatus(char *buf,int size)
+void Sas64000Gpi::gpoOneshotData(void *data)
 {
+  emit gpoChanged(sas_matrix,(long)data,false);
 }
