@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddbcheck.h,v 1.3 2007/02/14 21:59:12 fredg Exp $
+//      $Id: rddbcheck.h,v 1.5 2008-06-24 22:17:49 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -46,6 +46,13 @@ class MainObject : public QObject
   MainObject(QObject *parent=0,const char *name=0);
 
  private:
+  void CheckOrphanedTracks();
+  void CheckClocks();
+  void CheckEvents();
+  void CheckOrphanedTables();
+  void CleanTables(const QString &ext,QSqlQuery *table_q,QSqlQuery *name_q);
+  void CleanTables(const QString &ext,QSqlQuery *table_q);
+  bool IsTableLinked(QSqlQuery *name_q,const QString &ext,const QString &table);
   bool UserResponse();
   bool check_yes;
   bool check_no;
