@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdgpimon.cpp,v 1.10 2008-09-30 18:19:47 fredg Exp $
+//      $Id: rdgpimon.cpp,v 1.10.2.1 2008-12-08 16:44:21 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -120,10 +120,10 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 	  this,SLOT(gpiMaskChangedData(int,int,bool)));
   connect(gpi_ripc,SIGNAL(gpoMaskChanged(int,int,bool)),
 	  this,SLOT(gpoMaskChangedData(int,int,bool)));
-  connect(gpi_ripc,SIGNAL(gpiCartChanged(int,int,int)),
-	  this,SLOT(gpiCartChangedData(int,int,int)));
-  connect(gpi_ripc,SIGNAL(gpoCartChanged(int,int,int)),
-	  this,SLOT(gpoCartChangedData(int,int,int)));
+  connect(gpi_ripc,SIGNAL(gpiCartChanged(int,int,int,int)),
+	  this,SLOT(gpiCartChangedData(int,int,int,int)));
+  connect(gpi_ripc,SIGNAL(gpoCartChanged(int,int,int,int)),
+	  this,SLOT(gpoCartChangedData(int,int,int,int)));
   gpi_ripc->connectHost("localhost",RIPCD_TCP_PORT,gpi_config->password());
 
   //
@@ -172,7 +172,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   for(int i=0;i<GPIMON_ROWS;i++) {
     for(int j=0;j<GPIMON_COLS;j++) {
       gpi_labels[i*GPIMON_COLS+j]=new GpiLabel(this);
-      gpi_labels[i*GPIMON_COLS+j]->setGeometry(10+64*j,40+58*i,
+      gpi_labels[i*GPIMON_COLS+j]->setGeometry(10+64*j,40+70*i,
 					       gpi_labels[i*GPIMON_COLS+j]->
 					       sizeHint().width(),
 					       gpi_labels[i*GPIMON_COLS+j]->
@@ -196,6 +196,29 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   gpi_down_button->setGeometry(100,sizeHint().height()-60,80,50);
   connect(gpi_down_button,SIGNAL(clicked()),this,SLOT(downData()));
 
+  //
+  // Color Key
+  //
+  label=new QLabel(tr("Green = ON Cart"),this);
+  label->setGeometry(200,sizeHint().height()-50,300,12);
+  label->setFont(font);
+  label->setAlignment(AlignLeft|AlignVCenter);
+  QPalette p=palette();
+  p.setColor(QPalette::Active,QColorGroup::Foreground,darkGreen);
+  p.setColor(QPalette::Inactive,QColorGroup::Foreground,darkGreen);
+  p.setColor(QPalette::Disabled,QColorGroup::Foreground,darkGreen);
+  label->setPalette(p);
+
+  label=new QLabel(tr("Red = OFF Cart"),this);
+  label->setGeometry(200,sizeHint().height()-32,300,12);
+  label->setFont(font);
+  label->setAlignment(AlignLeft|AlignVCenter);
+  p.setColor(QPalette::Active,QColorGroup::Foreground,darkRed);
+  p.setColor(QPalette::Inactive,QColorGroup::Foreground,darkRed);
+  p.setColor(QPalette::Disabled,QColorGroup::Foreground,darkRed);
+  label->setPalette(p);
+
+
   //
   // Close Button
   //
@@ -222,7 +245,7 @@ MainWidget::~MainWidget()
 
 QSize MainWidget::sizeHint() const
 {
-  return QSize(528,58*GPIMON_ROWS+110);
+  return QSize(528,70*GPIMON_ROWS+110);
 }
 
 
@@ -340,39 +363,50 @@ void MainWidget::gpoMaskChangedData(int matrix,int line,bool state)
 }
 
 
-void MainWidget::gpiCartChangedData(int matrix,int line,int cartnum)
+void MainWidget::gpiCartChangedData(int matrix,int line,int off_cartnum,
+				    int on_cartnum)
 {
+//  printf("gpiCartChangedData(%d,%d,%d,%d)\n",matrix,line,off_cartnum,
+//	 on_cartnum);
+
   if(gpi_type_box->currentItem()!=RDMatrix::GpioInput) {
     return;
   }
-  if(cartnum<0) {
-    cartnum=0;
+  if(off_cartnum<0) {
+    off_cartnum=0;
+  }
+  if(on_cartnum<0) {
+    on_cartnum=0;
   }
   if(matrix!=gpi_matrix->matrix()) {
     return;
   }
   for(int i=0;i<(GPIMON_ROWS*GPIMON_COLS);i++) {
     if(gpi_labels[i]->line()==line) {
-      gpi_labels[i]->setCart(cartnum);
+      gpi_labels[i]->setCart(off_cartnum,on_cartnum);
     }
   }
 }
 
 
-void MainWidget::gpoCartChangedData(int matrix,int line,int cartnum)
+void MainWidget::gpoCartChangedData(int matrix,int line,int off_cartnum,
+  int on_cartnum)
 {
   if(gpi_type_box->currentItem()!=RDMatrix::GpioOutput) {
     return;
   }
-  if(cartnum<0) {
-    cartnum=0;
+  if(off_cartnum<0) {
+    off_cartnum=0;
+  }
+  if(on_cartnum<0) {
+    on_cartnum=0;
   }
   if(matrix!=gpi_matrix->matrix()) {
     return;
   }
   for(int i=0;i<(GPIMON_ROWS*GPIMON_COLS);i++) {
     if(gpi_labels[i]->line()==line) {
-      gpi_labels[i]->setCart(cartnum);
+      gpi_labels[i]->setCart(off_cartnum,on_cartnum);
     }
   }
 }
@@ -425,7 +459,7 @@ void MainWidget::UpdateLabelsUp(int last_line)
       tablename="GPOS";
       break;
   }
-  sql=QString().sprintf("select NUMBER,MACRO_CART from %s \
+  sql=QString().sprintf("select NUMBER,OFF_MACRO_CART,MACRO_CART from %s \
                          where (STATION_NAME=\"%s\")&&\
                          (MATRIX=%d)&&\
                          (NUMBER<=%d) order by NUMBER desc",
@@ -438,7 +472,8 @@ void MainWidget::UpdateLabelsUp(int last_line)
   }
   while(q->next()&&(count<count_limit)) {
     gpi_labels[count_limit-count-1]->setLine(q->value(0).toInt()-1);
-    gpi_labels[count_limit-count-1]->setCart(q->value(1).toUInt());
+    gpi_labels[count_limit-count-1]->
+      setCart(q->value(1).toUInt(),q->value(2).toUInt());
     gpi_labels[count_limit-count-1]->show();
     if(!last_updated) {
       gpi_last_line=q->value(0).toInt();
@@ -472,7 +507,7 @@ void MainWidget::UpdateLabelsDown(int first_line)
       tablename="GPOS";
       break;
   }
-  sql=QString().sprintf("select NUMBER,MACRO_CART from %s \
+  sql=QString().sprintf("select NUMBER,OFF_MACRO_CART,MACRO_CART from %s \
                          where (STATION_NAME=\"%s\")&&\
                          (MATRIX=%d)&&\
                          (NUMBER>=%d) order by NUMBER",
@@ -482,7 +517,7 @@ void MainWidget::UpdateLabelsDown(int first_line)
   q=new RDSqlQuery(sql);
   while(q->next()&&(count<(GPIMON_ROWS*GPIMON_COLS))) {
     gpi_labels[count]->setLine(q->value(0).toInt()-1);
-    gpi_labels[count]->setCart(q->value(1).toUInt());
+    gpi_labels[count]->setCart(q->value(1).toUInt(),q->value(2).toUInt());
     gpi_labels[count]->show();
     if(!first_updated) {
       gpi_first_line=q->value(0).toInt();
