@@ -2,9 +2,9 @@
 //
 // A Batch Importer for Rivendell.
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport.cpp,v 1.23 2008-10-10 12:32:23 fredg Exp $
+//      $Id: rdimport.cpp,v 1.23.2.2 2008-11-30 00:33:04 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -75,8 +75,10 @@ MainObject::MainObject(QObject *parent,const char *name)
   import_delete_cuts=false;
   import_drop_box=false;
   import_stdin_specified=false;
+  import_startdate_offset=0;
+  import_enddate_offset=0;
   import_fix_broken_formats=false;
-
+  import_persistent_dropbox_id=-1;
 
   //
   // Read Command Options
@@ -129,9 +131,27 @@ MainObject::MainObject(QObject *parent,const char *name)
     if(import_cmd->key(i)=="--delete-cuts") {
       import_delete_cuts=true;
     }
+    if(import_cmd->key(i)=="--startdate-offset") {
+      import_startdate_offset=import_cmd->value(i).toInt(&ok);
+      if(!ok) {
+	fprintf(stderr,"rdimport: invalid startdate-offset\n");
+	delete import_cmd;
+	exit(256);
+      }
+    }
+    if(import_cmd->key(i)=="--enddate-offset") {
+      import_enddate_offset=import_cmd->value(i).toInt(&ok);
+      if(!ok) {
+	fprintf(stderr,"rdimport: invalid enddate-offset\n");
+	delete import_cmd;
+	exit(256);
+      }
+    }
     if(import_cmd->key(i)=="--drop-box") {
       import_drop_box=true;
-      import_delete_source=true;
+      if(import_persistent_dropbox_id<0) {
+	import_delete_source=true;
+      }
     }
     if(import_cmd->key(i)=="--metadata-pattern") {
       import_metadata_pattern=import_cmd->value(i);
@@ -144,6 +164,14 @@ MainObject::MainObject(QObject *parent,const char *name)
     if(import_cmd->key(i)=="--fix-broken-formats") {
       import_fix_broken_formats=true;
     }
+    if(import_cmd->key(i)=="--persistent-dropbox-id") {
+      import_persistent_dropbox_id=import_cmd->value(i).toInt(&ok);
+      if(!ok) {
+	fprintf(stderr,"rdimport: invalid persistent dropbox id\n");
+	delete import_cmd;
+	exit(256);
+      }
+    }
   }
 
   //
@@ -337,12 +365,17 @@ MainObject::MainObject(QObject *parent,const char *name)
       printf(" Using metadata pattern: %s\n",
 	     (const char *)import_metadata_pattern);
     }
+    printf(" Start Date Offset = %d days\n",import_startdate_offset);
+    printf(" End Date Offset = %d days\n",import_enddate_offset);
     if(import_fix_broken_formats) {
       printf(" Broken format workarounds are ENABLED\n");
     }
     else {
       printf(" Broken format workarounds are DISABLED\n");
     }
+    if(import_persistent_dropbox_id>=0) {
+      printf(" Persistent DropBox ID = %d\n",import_persistent_dropbox_id);
+    }
     printf(" Files to process:\n");
     for(unsigned i=import_file_key;i<import_cmd->keys();i++) {
       printf("   \"%s\"\n",(const char *)import_cmd->key(i));
@@ -473,13 +506,7 @@ void MainObject::ProcessFileList(const QString &flist)
   QString entry;
 
   for(unsigned i=0;i<flist.length();i++) {
-//    if(flist.at(i)==',') {
-//      ProcessFileEntry(entry);
-//      entry="";
-//    }
-//    else {
-      entry+=flist.at(i);
-//    }
+    entry+=flist.at(i);
   }
   ProcessFileEntry(entry);
 }
@@ -530,7 +557,8 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   unsigned length_deviation=0;
   QString effective_filename;
   bool found_cart=false;
-
+  QDateTime dt;
+  bool ok=false;
   RDGroup *effective_group=new RDGroup(import_group->name());
   RDWaveData *wavedata=new RDWaveData();
   RDWaveFile *wavefile=new RDWaveFile(filename);
@@ -762,12 +790,16 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
     cut->setMetadata(wavedata);
   }
   if(wavedata->title().length()==0 || ( (wavedata->title().length()>0) && (wavedata->title()[0] == '\0')) ) {
+    QString title=effective_group->defaultTitle();
+    QString basename=RDGetBasePart(filename);
+    int ptr=basename.findRev(".");
+    title.replace("%p",RDGetPathPart(filename));
+    title.replace("%f",basename.left(ptr));
+    title.replace("%e",basename.right(basename.length()-ptr-1));
     if(cart_created) {
-      cart->setTitle(QString().sprintf("Imported from %s",
-		     (const char *)RDGetBasePart(filename).utf8()));
+      cart->setTitle(title.utf8());
     }
-    cut->setDescription(QString().sprintf("Imported from %s",
-			(const char *)RDGetBasePart(filename)).utf8());
+    cut->setDescription(title.utf8());
   }
 
   if(import_title_from_cartchunk_cutid) {
@@ -782,6 +814,18 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
   cart->resetRotation();
   cart->calculateAverageLength(&length_deviation);
   cart->setLengthDeviation(length_deviation);
+  if(import_startdate_offset!=0) {
+    dt=cut->startDatetime(&ok);
+    if(ok) {
+      cut->setStartDatetime(dt.addDays(import_startdate_offset),true);
+    }
+  }
+  if(import_enddate_offset!=0) {
+    dt=cut->endDatetime(&ok);
+    if(ok) {
+      cut->setEndDatetime(dt.addDays(import_enddate_offset),true);
+    }
+  }
   if(import_verbose) {
     printf("done.\n");
     fflush(stdout);
@@ -818,49 +862,55 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
 void MainObject::VerifyFile(const QString &filename,unsigned *cartnum)
 {
   bool found=false;
+  QDateTime dt;
 
   for(std::list<struct DropboxList *>::const_iterator 
 	ci=import_dropbox_list.begin();
       ci!=import_dropbox_list.end();ci++) {
     if((*ci)->filename==filename) {
       found=true;
-      QFile *file=new QFile(filename);
-      if((file->size()==(*ci)->size)&&(!(*ci)->failed)) {
-	(*ci)->pass++;
-      }
-      else {
-	(*ci)->size=file->size();
-	(*ci)->pass=0;
-      }
-      if((*ci)->failed) {
-	(*ci)->checked=true;
-	if(file->size()!=(*ci)->size) {
-	  (*ci)->failed=false;
+      QFileInfo *file=new QFileInfo(filename);
+      dt=GetCachedTimestamp(filename);
+      if(dt.isNull()||(file->lastModified()>dt)) {
+	if((file->size()==(*ci)->size)&&(!(*ci)->failed)) {
+	  (*ci)->pass++;
+	}
+	else {
 	  (*ci)->size=file->size();
 	  (*ci)->pass=0;
 	}
-      }
-      delete file;
-      if((*ci)->pass>=RDIMPORT_DROPBOX_PASSES) {
-	switch(ImportFile(filename,cartnum)) {
+	if((*ci)->failed) {
+	  (*ci)->checked=true;
+	  if(file->size()!=(*ci)->size) {
+	    (*ci)->failed=false;
+	    (*ci)->size=file->size();
+	    (*ci)->pass=0;
+	  }
+	}
+	if((*ci)->pass>=RDIMPORT_DROPBOX_PASSES) {
+	  switch(ImportFile(filename,cartnum)) {
 	    case MainObject::Success:
+	      WriteTimestampCache(filename,file->lastModified());
 	      break;
-
+	      
 	    case MainObject::FileBad:
 	      (*ci)->failed=true;
 	      (*ci)->checked=true;
 	      (*ci)->pass=0;
+	      WriteTimestampCache(filename,file->lastModified());
 	      break;
-
+	      
 	    case MainObject::NoCart:
 	      (*ci)->pass=0;
 	      (*ci)->checked=true;
 	      break;
+	  }
+	}
+	else {
+	  (*ci)->checked=true;
 	}
       }
-      else {
-	(*ci)->checked=true;
-      }
+      delete file;
     }
   }
   if(!found) {
@@ -1260,6 +1310,56 @@ void MainObject::DeleteCuts(unsigned cartnum)
 }
 
 
+QDateTime MainObject::GetCachedTimestamp(const QString &filename)
+{
+  QString sql;
+  RDSqlQuery *q;
+  QDateTime dt;
+  if(import_persistent_dropbox_id<0) {
+    return dt;
+  }
+  sql=QString().sprintf("select FILE_DATETIME from DROPBOX_PATHS \
+                         where (DROPBOX_ID=%d)&&(FILE_PATH=\"%s\")",
+			import_persistent_dropbox_id,
+			(const char *)RDEscapeString(filename));
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    dt=q->value(0).toDateTime();
+  }
+  delete q;
+  return dt;
+}
+
+
+void MainObject::WriteTimestampCache(const QString &filename,
+				     const QDateTime &dt)
+{
+  QString sql;
+  RDSqlQuery *q;
+  if(import_persistent_dropbox_id<0) {
+    return;
+  }
+  if(GetCachedTimestamp(filename).isNull()) {
+    sql=QString().sprintf("insert into DROPBOX_PATHS set \
+                           DROPBOX_ID=%d,\
+                           FILE_PATH=\"%s\",\
+                           FILE_DATETIME=\"%s\"",
+			  import_persistent_dropbox_id,
+			  (const char *)RDEscapeString(filename),
+			  (const char *)dt.toString("yyyy-MM-dd hh:mm:ss"));
+  }
+  else {
+    sql=QString().sprintf("update DROPBOX_PATHS set FILE_DATETIME=\"%s\" \
+                           where (DROPBOX_ID=%d)&&(FILE_PATH=\"%s\")",
+			  (const char *)dt.toString("yyyy-MM-dd hh:mm:ss"),
+			  import_persistent_dropbox_id,
+			  (const char *)RDEscapeString(filename));
+  }
+  q=new RDSqlQuery(sql);
+  delete q;
+}
+
+
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv,false);
